@@ -6,6 +6,8 @@
 #include "bodypart.h"
 #include <sstream>
 
+#define MIN_DISEASE_AGE (-43200) // Permanent disease capped @ 3 days
+
 struct game;
 
 void dis_msg(game *g, dis_type type)
@@ -53,6 +55,9 @@ void dis_msg(game *g, dis_type type)
  case DI_FORMICATION:
   g->add_msg("There's bugs crawling under your skin!");
   break;
+ case DI_WEBBED:
+  g->add_msg("You're covered in webs!");
+  break;
  case DI_DRUNK:
  case DI_HIGH:
   g->add_msg("You feel lightheaded.");
@@ -67,6 +72,9 @@ void dis_msg(game *g, dis_type type)
  case DI_BLIND:
   g->add_msg("You're blinded!");
   break;
+ case DI_AMIGARA:
+  g->add_msg("You can't look away from the fautline...");
+  break;
  }
 }
   
@@ -298,11 +306,11 @@ void dis_effect(game *g, player &p, disease &dis)
 
  case DI_SLEEP:
   p.moves = 0;
-  if (g->turn % 25 == 0) {
+  if (int(g->turn) % 25 == 0) {
    if (p.fatigue > 0)
-    p.fatigue -= rng(1, 2);
-   if (p.has_trait(PF_FASTHEALER) && one_in(2))
-    p.healall(rng(0, 1));	// Sum chance of 1/4, PLUS normal rate
+    p.fatigue -= 1 + rng(0, 1) * rng(0, 1);
+   if (p.has_trait(PF_FASTHEALER))
+    p.healall(rng(0, 1));
    else
     p.healall(rng(0, 1) * rng(0, 1) * rng(0, 1));
    if (p.fatigue <= 0 && p.fatigue > -20) {
@@ -311,14 +319,14 @@ void dis_effect(game *g, player &p, disease &dis)
     dis.duration = dice(3, 100);
    }
   }
-  if (g->turn % 100 == 0) {
+  if (int(g->turn) % 100 == 0 && !p.has_bionic(bio_recycler)) {
 // Hunger and thirst advance more slowly while we sleep.
    p.hunger--;
    p.thirst--;
   }
   if (rng(5, 80) + rng(0, 120) + rng(0, abs(p.fatigue)) +
       rng(0, abs(p.fatigue * 5)) < g->light_level() &&
-      (p.fatigue < 10 || one_in(p.fatigue / 10))) {
+      (p.fatigue < 10 || one_in(p.fatigue / 2))) {
    g->add_msg("The light wakes you up.");
    dis.duration = 1;
   }
@@ -414,6 +422,23 @@ void dis_effect(game *g, player &p, disease &dis)
    p.str_cur -= 2;
   break;
 
+ case DI_BADPOISON:
+  if ((!p.has_trait(PF_POISRESIST) && one_in(100)) ||
+      ( p.has_trait(PF_POISRESIST) && one_in(500))   ) {
+   if (!p.is_npc())
+    g->add_msg("You're suddenly wracked with pain!");
+   p.pain += 2;
+   p.hurt(g, bp_torso, 0, rng(0, 2));
+  }
+  p.per_cur -= 2;
+  p.dex_cur -= 2;
+  p.moves -= 10;
+  if (!p.has_trait(PF_POISRESIST))
+   p.str_cur -= 3;
+  else
+   p.str_cur--;
+  break;
+
  case DI_FOODPOISON:
   bonus = 0;
   if (p.has_trait(PF_POISRESIST))
@@ -497,14 +522,21 @@ void dis_effect(game *g, player &p, disease &dis)
   }
  } break;
 
+ case DI_WEBBED:
+  p.str_cur -= 2;
+  p.dex_cur -= 4;
+  p.moves -= 25;
+  break;
+
  case DI_FORMICATION:
   p.int_cur -= 2;
   p.str_cur -= 1;
-  if (one_in(300 * p.int_cur)) {
+  if (one_in(50 * p.int_cur)) {
    int t;
-   if (!p.is_npc())
+   if (!p.is_npc()) {
     g->add_msg("You start scratching yourself all over!");
-   else if (g->u_see(p.posx, p.posy, t))
+    g->cancel_activity();
+   } else if (g->u_see(p.posx, p.posy, t))
     g->add_msg("%s starts scratching %s all over!", p.name.c_str(),
                (p.male ? "himself" : "herself"));
    p.moves -= 150;
@@ -602,7 +634,7 @@ void dis_effect(game *g, player &p, disease &dis)
     if (!p.is_npc())
      g->add_msg("Glowing lights surround you, and you teleport.");
     g->teleport();
-    if (one_in(4))
+    if (one_in(10))
      p.rem_disease(DI_TELEGLOW);
    }
    if (one_in(1200 - ((dis.duration - 6000) / 5)) && one_in(20)) {
@@ -698,9 +730,11 @@ std::string dis_name(disease dis)
  case DI_SLIMED:	return "Slimed";
  case DI_BLIND:		return "Blind";
  case DI_POISON:	return "Poisoned";
+ case DI_BADPOISON:	return "Badly Poisoned";
  case DI_FOODPOISON:	return "Food Poisoning";
  case DI_SHAKES:	return "Shakes";
  case DI_FORMICATION:	return "Bugs Under Skin";
+ case DI_WEBBED:	return "Webbed";
  case DI_DRUNK:
   if (dis.duration > 2200) return "Wasted";
   if (dis.duration > 1400) return "Trashed";
@@ -832,6 +866,11 @@ Range of Sight: 0";
 Perception - 1;    Dexterity - 1;   Strength - 2 IF not resistant\n\
 Occasional pain and/or damage.";
 
+ case DI_BADPOISON:	return "\
+Perception - 2;    Dexterity - 2;\n\
+Strength - 3 IF not resistant, -1 otherwise\n\
+Frequent pain and/or damage.";
+
  case DI_FOODPOISON:	return "\
 Speed - 35%;     Strength - 3;     Dexterity - 1;     Perception - 1\n\
 Your stomach is extremely upset, and you keep having pangs of pain and nausea.";
@@ -844,6 +883,9 @@ Strength - 1;     Intelligence - 2;\n\
 You stop to scratch yourself frequently; high intelligence helps you resist\n\
 this urge.";
 
+ case DI_WEBBED:	return "\
+Strength - 1;     Dexterity - 4;    Speed - 25";
+
  case DI_DRUNK:
   perpen = int(dis.duration / 1000);
   dexpen = int(dis.duration / 1000);
