@@ -11,6 +11,8 @@ enum event_type {
  EVENT_HELP,
  EVENT_WANTED,
  EVENT_ROBOT_ATTACK,
+ EVENT_SPAWN_WYRMS,
+ EVENT_AMIGARA,
  NUM_EVENT_TYPES
 };
 
