@@ -153,9 +153,8 @@ bool map::process_fields(game *g)
          add_field(g, x+i, y+j, fd_fire, 1);
 // If we're not spreading, maybe we'll stick out some smoke, huh?
        } else if (move_cost(x+i, y+j) > 0 &&
-                  rng(7, 40) < cur->density * 10 && cur->age < 1000) {
+                  rng(7, 40) < cur->density * 10 && cur->age < 1000)
         add_field(g, x+i, y+j, fd_smoke, rng(1, cur->density));
-       }
       }
      }
     }
@@ -173,7 +172,7 @@ bool map::process_fields(game *g)
      for (int a = -1; a <= 1; a++) {
       for (int b = -1; b <= 1; b++) {
        if ((field_at(x+a, y+b).type == fd_smoke &&
-             field_at(x+a, y+b).density < 3)      ||
+             field_at(x+a, y+b).density < 3       ) ||
            (field_at(x+a, y+b).is_null() && move_cost(x+a, y+b) > 0))
         spread.push_back(point(x+a, y+b));
       }
@@ -235,6 +234,51 @@ bool map::process_fields(game *g)
     }
     break;
 
+   case fd_toxic_gas:
+// Reset nearby scents to zero
+    for (int i = -1; i <= 1; i++) {
+     for (int j = -1; j <= 1; j++)
+      g->scent(x+i, y+j) = 0;
+    }
+    if (is_outside(x, y))
+     cur->age += 40;
+    if (one_in(2)) {
+     std::vector <point> spread;
+// Pick all eligible points to spread to
+     for (int a = -1; a <= 1; a++) {
+      for (int b = -1; b <= 1; b++) {
+       if (((field_at(x+a, y+b).type == fd_smoke ||
+             field_at(x+a, y+b).type == fd_tear_gas ||
+             field_at(x+a, y+b).type == fd_toxic_gas ||
+             field_at(x+a, y+b).type == fd_nuke_gas   ) &&
+             field_at(x+a, y+b).density < 3            )      ||
+           (field_at(x+a, y+b).is_null() && move_cost(x+a, y+b) > 0))
+        spread.push_back(point(x+a, y+b));
+      }
+     }
+// Then, spread to a nearby point
+     if (cur->density > 0 && cur->age > 0 && spread.size() > 0) {
+      point p = spread[rng(0, spread.size() - 1)];
+// Nearby toxic gas grows thicker
+      if (field_at(p.x, p.y).type == fd_toxic_gas &&
+          field_at(p.x, p.y).density < 3) {
+        field_at(p.x, p.y).density++;
+        cur->density--;
+// Nearby smoke & teargas is converted into toxic gas
+      } else if (field_at(p.x, p.y).type == fd_smoke ||
+                 field_at(p.x, p.y).type == fd_tear_gas) {
+       field_at(p.x, p.y).type = fd_toxic_gas;
+// Or, just create a new field.
+      } else if (cur->density > 0 && move_cost(p.x, p.y) > 0 &&
+                 add_field(g, p.x, p.y, fd_toxic_gas, 1)) {
+       cur->density--;
+       field_at(p.x, p.y).age = cur->age;
+      }
+     }
+    }
+    break;
+
+
    case fd_nuke_gas:
 // Reset nearby scents to zero
     for (int i = -1; i <= 1; i++) {
@@ -252,6 +296,7 @@ bool map::process_fields(game *g)
       for (int b = -1; b <= 1; b++) {
        if (((field_at(x+a, y+b).type == fd_smoke ||
              field_at(x+a, y+b).type == fd_tear_gas ||
+             field_at(x+a, y+b).type == fd_toxic_gas ||
              field_at(x+a, y+b).type == fd_nuke_gas   ) &&
              field_at(x+a, y+b).density < 3            )      ||
            (field_at(x+a, y+b).is_null() && move_cost(x+a, y+b) > 0))
@@ -266,8 +311,9 @@ bool map::process_fields(game *g)
           field_at(p.x, p.y).density < 3) {
         field_at(p.x, p.y).density++;
         cur->density--;
-// Nearby smoke & teargas is converted into nukegas
+// Nearby smoke, tear, and toxic gas is converted into nukegas
       } else if (field_at(p.x, p.y).type == fd_smoke ||
+                 field_at(p.x, p.y).type == fd_toxic_gas ||
                  field_at(p.x, p.y).type == fd_tear_gas) {
        field_at(p.x, p.y).type = fd_nuke_gas;
 // Or, just create a new field.
@@ -322,9 +368,9 @@ bool map::process_fields(game *g)
     break;
 
    case fd_fatigue:
-    if (cur->density < 3 && g->turn % 3600 == 0 && one_in(10))
+    if (cur->density < 3 && int(g->turn) % 3600 == 0 && one_in(10))
      cur->density++;
-    else if (cur->density == 3 && one_in(3600)) { // Spawn nether creature!
+    else if (cur->density == 3 && one_in(600)) { // Spawn nether creature!
      mon_id type = mon_id(rng(mon_flying_polyp, mon_blank));
      monster creature(g->mtypes[type]);
      creature.spawn(x + rng(-3, 3), y + rng(-3, 3));
@@ -357,6 +403,13 @@ void map::step_in_field(int x, int y, game *g)
   case fd_bile:		// Ditto
    return;
 
+  case fd_web: {
+   int web = cur->density * 5 - g->u.disease_level(DI_WEBBED);
+   if (web > 0)
+    g->u.add_disease(DI_WEBBED, web, g);
+   field_at(x, y) = field();
+  } break;
+
   case fd_acid:
    if (cur->density == 3) {
     g->add_msg("The acid burns your legs and feet!");
@@ -384,25 +437,37 @@ void map::step_in_field(int x, int y, game *g)
      g->u.hit(g, bp_legs, 0, 0,  rng(2, 6));
      g->u.hit(g, bp_legs, 1, 0,  rng(2, 6));
      g->u.hit(g, bp_torso, 0, 4, rng(4, 9));
-     g->u.infect(DI_SMOKE, bp_mouth, 5, 20, g);
     } else if (cur->density == 3) {
      g->add_msg("You're set ablaze!");
      g->u.hit(g, bp_legs, 0, 0, rng(2, 6));
      g->u.hit(g, bp_legs, 1, 0, rng(2, 6));
      g->u.hit(g, bp_torso, 0, 4, rng(4, 9));
      g->u.add_disease(DI_ONFIRE, 5, g);
-     g->u.infect(DI_SMOKE, bp_mouth, 7, 30, g);
     }
+    if (cur->density == 2)
+     g->u.infect(DI_SMOKE, bp_mouth, 5, 20, g);
+    else if (cur->density == 3)
+     g->u.infect(DI_SMOKE, bp_mouth, 7, 30, g);
    }
    break;
+
   case fd_smoke:
    if (cur->density == 3)
     g->u.infect(DI_SMOKE, bp_mouth, 4, 15, g);
    break;
+
   case fd_tear_gas:
    if (cur->density > 1 || !one_in(3))
     g->u.infect(DI_TEARGAS, bp_mouth, 5, 20, g);
    break;
+
+  case fd_toxic_gas:
+   if (cur->density == 2)
+    g->u.infect(DI_POISON, bp_mouth, 5, 30, g);
+   else if (cur->density == 3)
+    g->u.infect(DI_BADPOISON, bp_mouth, 5, 30, g);
+   break;
+
   case fd_nuke_gas:
    g->u.radiation += rng(0, cur->density * (cur->density + 1));
    if (cur->density == 3) {
@@ -410,6 +475,7 @@ void map::step_in_field(int x, int y, game *g)
     g->u.hurtall(rng(1, 3));
    }
    break;
+
   case fd_electricity:
    g->add_msg("You're electrocuted!");
    g->u.hurtall(rng(1, cur->density));
@@ -418,6 +484,7 @@ void map::step_in_field(int x, int y, game *g)
     g->u.moves -= cur->density * 150;
    }
    break;
+
   case fd_fatigue:
    if (rng(0, 2) < cur->density) {
     g->add_msg("You're violently teleported!");
@@ -440,6 +507,12 @@ void map::mon_in_field(int x, int y, game *g, monster *z)
   case fd_bile:		// Ditto
    break;
 
+  case fd_web:
+   if (!z->has_flag(MF_WEBWALK)) {
+    z->speed *= .8;
+    field_at(x, y) = field();
+   }
+
   case fd_acid:
    if (!z->has_flag(MF_DIGS) && !z->has_flag(MF_FLIES) &&
        !z->has_flag(MF_ACIDPROOF)) {
@@ -505,6 +578,12 @@ void map::mon_in_field(int x, int y, game *g, monster *z)
     dam += cur->density * 10;
    }
    break;
+
+  case fd_toxic_gas:
+   dam = cur->density;
+   z->speed -= cur->density;
+   break;
+
   case fd_nuke_gas:
    if (cur->density == 3) {
     z->speed -= rng(60, 120);
@@ -557,7 +636,8 @@ void map::mon_in_field(int x, int y, game *g, monster *z)
    break;
      
  }
- z->hurt(dam);
+ if (dam > 0)
+  z->hurt(dam);
 }
 
 bool vector_has(std::vector <item> vec, itype_id type)
