@@ -124,6 +124,11 @@ void item::make(itype* it)
  contents.clear();
 }
 
+bool item::is_null()
+{
+ return (type == NULL || type->id == 0);
+}
+
 item item::in_its_container(std::vector<itype*> *itypes)
 {
  if (!is_food() || (dynamic_cast<it_comest*>(type))->container == itm_null)
@@ -135,6 +140,27 @@ item item::in_its_container(std::vector<itype*> *itypes)
  return ret;
 }
 
+bool item::invlet_is_okay()
+{
+ return ((invlet >= 'a' & invlet <= 'z') || (invlet >= 'A' && invlet <= 'Z'));
+}
+
+bool item::stacks_with(item rhs)
+{
+ bool stacks = (type   == rhs.type   && damage  == rhs.damage  &&
+                active == rhs.active && charges == rhs.charges &&
+                contents.size() == rhs.contents.size() &&
+                (!goes_bad() || bday == rhs.bday));
+
+ if (contents.size() != rhs.contents.size())
+  return false;
+
+ for (int i = 0; i < contents.size() && stacks; i++)
+   stacks &= contents[i].stacks_with(rhs.contents[i]);
+
+ return stacks;
+}
+ 
 void item::put_in(item payload)
 {
  contents.push_back(payload);
@@ -228,13 +254,13 @@ std::string item::info(bool showtext)
  if (is_food()) {
 
   it_comest* food = dynamic_cast<it_comest*>(type);
-  dump << " Nutrituion: " << int(food->nutr) << "\n Quench: " <<
+  dump << " Nutrition: " << int(food->nutr) << "\n Quench: " <<
           int(food->quench) << "\n Enjoyability: " << int(food->fun);
 
  } else if (is_food_container()) {
 
   it_comest* food = dynamic_cast<it_comest*>(contents[0].type);
-  dump << " Nutrituion: " << int(food->nutr) << "\n Quench: " <<
+  dump << " Nutrition: " << int(food->nutr) << "\n Quench: " <<
           int(food->quench) << "\n Enjoyability: " << int(food->fun);
 
  } else if (is_ammo()) {
@@ -504,7 +530,7 @@ std::string item::tname(game *g)
  else if (is_food_container())
   food = dynamic_cast<it_comest*>(contents[0].type);
  if (food != NULL && g != NULL && food->spoils != 0 &&
-     g->turn - bday > food->spoils * 600)
+     int(g->turn) - bday > food->spoils * 600)
   ret << " (rotten)";
 
 
@@ -587,11 +613,37 @@ int item::attack_time()
  return 50 + 4 * volume() + 2 * weight();
 }
 
+int item::damage_bash()
+{
+ return type->melee_dam;
+}
+
+int item::damage_cut()
+{
+ return type->melee_cut;
+}
+
 bool item::has_flag(item_flag f)
 {
  return (type->item_flags & mfb(f));
 }
 
+bool item::rotten(game *g)
+{
+ if (!is_food() || g == NULL)
+  return false;
+ it_comest* food = dynamic_cast<it_comest*>(type);
+ return (food->spoils != 0 && int(g->turn) - bday > food->spoils * 600);
+}
+
+bool item::goes_bad()
+{
+ if (!is_food())
+  return false;
+ it_comest* food = dynamic_cast<it_comest*>(type);
+ return (food->spoils != 0);
+}
+
 int item::weapon_value(int skills[num_skill_types])
 {
  int my_value = 0;
@@ -660,6 +712,11 @@ bool item::conductive()
  return false;
 }
 
+bool item::destroyed_at_zero_charges()
+{
+ return (is_ammo() || is_food());
+}
+
 bool item::is_gun()
 {
  return type->is_gun();
@@ -682,8 +739,12 @@ bool item::is_ammo()
 
 bool item::is_food(player *u)
 {
+ if (u == NULL)
+  return is_food();
+
  if (type->is_food())
   return true;
+
  if (u->has_bionic(bio_batteries) && is_ammo() &&
      (dynamic_cast<it_ammo*>(type))->type == AT_BATT)
   return true;
@@ -764,6 +825,13 @@ bool item::is_macguffin()
  return type->is_macguffin();
 }
 
+bool item::is_other()
+{
+ return (!is_gun() && !is_ammo() && !is_armor() && !is_food() &&
+         !is_food_container() && !is_tool() && !is_gunmod() && !is_bionic() &&
+         !is_book() && !is_weap());
+}
+
 int item::reload_time(player &u)
 {
  int ret = 0;
@@ -1022,42 +1090,7 @@ void item::use(player &u)
   charges--;
 }
 
-/*
-bool item::stack_with(item &it)
-{
- if (type->id != it.type->id || damage != it.damage ||
-     charges != it.charges || owned != it.owned || active != it.active ||
-     ((is_food() || is_food_container()) && bday != it.bday))
-  return false;
-
- if (contents.size() > 0) {
-  if (contents.size() != it.contents.size())
-   return false;
-  std::vector<int> tmp_contents; // Duplicate it to check if it matches
-  for (int i = 0; i < it.contents.size(); i++)
-   tmp_contents.push_back(it.contents[i].type->id);
-  for (int i = 0; i < contents.size(); i++) {
-   for (int j = 0; j < tmp_contents.size(); j++) {
-    if (tmp_contents[j] == contents[i].type->id) {
-    tmp_contents.erase(tmp_contents.begin() + j);
-     j = tmp_contents.size();
-    }
-   }
-  }
-// At this point, tmp_contents should be empty if it's a perfect match
-  if (!tmp_contents.empty())
-   return false;
- }
-
- count++;
- return true;
-}
-*/
-
 bool is_flammable(material m)
 {
- if (m == VEGGY   || m == FLESH || m == POWDER || m == COTTON || m == WOOL ||
-     m == LEATHER || m == PAPER || m == WOOD   || m == MNULL)
-  return true;
- return false;
+ return (m == COTTON || m == WOOL || m == PAPER || m == WOOD || m == MNULL);
 }
