@@ -20,7 +20,7 @@ enum itype_id {
 itm_null = 0,
 itm_corpse,
 // Drinks
-itm_water, itm_water_dirty, itm_salt_water, itm_oj, itm_apple_cider,
+itm_water, itm_water_dirty, itm_sewage, itm_salt_water, itm_oj, itm_apple_cider,
  itm_energy_drink, itm_cola, itm_rootbeer, itm_milk, itm_V8, itm_broth,
  itm_soup, itm_whiskey, itm_vodka, itm_rum, itm_tequila, itm_beer, itm_bleach,
  itm_ammonia, itm_mutagen, itm_purifier,
@@ -54,7 +54,8 @@ itm_wrapper, itm_syringe, itm_rag, itm_fur, itm_leather, itm_superglue,
  itm_pan, itm_knife_butter, itm_knife_steak, itm_knife_butcher,
  itm_knife_combat, itm_2x4, itm_muffler, itm_pipe, itm_bat, itm_machete,
  itm_katana, itm_spear_wood, itm_spear_knife, itm_baton, itm_bee_sting,
- itm_wasp_sting, itm_chitin_piece, itm_canister_empty, itm_gold,
+ itm_wasp_sting, itm_chitin_piece, itm_canister_empty, itm_gold, itm_coal,
+ itm_petrified_eye, itm_spiral_stone,
 // Footwear
 itm_sneakers, itm_boots, itm_boots_steel, itm_boots_winter, itm_mocassins,
  itm_flip_flops, itm_dress_shoes, itm_heels, 
@@ -114,9 +115,9 @@ itm_mag_porn, itm_mag_tv, itm_mag_news, itm_mag_cars, itm_mag_cooking,
  itm_novel_drama, itm_manual_brawl, itm_manual_knives, itm_manual_mechanics,
  itm_manual_speech, itm_manual_business, itm_manual_first_aid,
  itm_manual_computers, itm_cookbook, itm_manual_electronics,
- itm_manual_tailor, itm_manual_traps, itm_textbook_computers,
- itm_textbook_electronics, itm_textbook_business, itm_textbook_chemistry,
- itm_SICP, itm_textbook_robots,
+ itm_manual_tailor, itm_manual_traps, itm_manual_carpentry,
+ itm_textbook_computers, itm_textbook_electronics, itm_textbook_business,
+ itm_textbook_chemistry, itm_textbook_carpentry, itm_SICP, itm_textbook_robots,
 // Containers
 itm_bag_plastic, itm_bottle_plastic, itm_bottle_glass,
  itm_can_drink, itm_can_food, itm_box_small,
@@ -132,7 +133,7 @@ itm_lighter, itm_sewing_kit, itm_scissors, itm_hammer, itm_extinguisher,
  itm_smokebomb, itm_smokebomb_act, itm_molotov, itm_molotov_lit, itm_dynamite,
  itm_dynamite_act, itm_mininuke, itm_mininuke_act, itm_pheromone, itm_portal,
  itm_bot_manhack, itm_bot_turret, itm_UPS_off, itm_UPS_on, itm_tazer, itm_mp3,
- itm_mp3_on,
+ itm_mp3_on, itm_vortex_stone,
 // Bionics containers
 itm_bionics_battery,       itm_bionics_power,   itm_bionics_tools,
  itm_bionics_neuro,        itm_bionics_sensory, itm_bionics_aquatic,
@@ -173,6 +174,10 @@ NUM_AMMO_TYPES
 
 enum item_flag {
 IF_NULL,
+
+IF_LIGHT_4,	// Provides 4 tiles of light
+IF_LIGHT_8,	// Provides 8 tiles of light
+
 IF_SPEAR,	// Cutting damage is actually a piercing attack
 IF_STAB,	// This weapon *can* pierce, but also has normal cutting
 IF_WRAP,	// Can wrap around your target, costing you and them movement
