@@ -5,8 +5,19 @@
 #include "output.h"
 #include "rng.h"
 #include "line.h"
+#include "player.h"
 #include <sstream>
 
+/* To mark an item as "removed from inventory", set its invlet to 0
+   This is useful for traps (placed on ground), inactive bots, etc
+ */
+void iuse::sewage(game *g, player *p, item *it, bool t)
+{
+ p->vomit(g);
+ if (one_in(4))
+  p->mutate(g);
+}
+
 void iuse::royal_jelly(game *g, player *p, item *it, bool t)
 {
 // TODO: Add other diseases here; royal jelly is a cure-all!
@@ -407,7 +418,7 @@ void iuse::coke(game *g, player *p, item *it, bool t)
 void iuse::meth(game *g, player *p, item *it, bool t)
 {
  int duration = 10 * (40 - p->str_cur);
- if (p->has_amount(itm_lighter, 1)) {
+ if (p->has_charges(itm_lighter, 1)) {
   if (!p->is_npc())
    g->add_msg("You smoke some crystals.");
   duration *= 1.5;
@@ -502,20 +513,11 @@ void iuse::purifier(game *g, player *p, item *it, bool t)
 {
  std::vector<int> valid;	// Which flags the player has
  for (int i = 0; i < PF_MAX2; i++) {
-  if (p->has_trait(pl_flag(i)) && traits[i].curable)
+  if (p->has_mutation(pl_flag(i))|| p->has_trait(pl_flag(i)) && traits[i].curable)
    valid.push_back(i);
  }
  if (valid.size() == 0) {
-  int stat_raised = rng(1, 4);
-  std::string adj;
-  switch (stat_raised) {
-   case 1: adj = "stronger";		p->str_max++;	break;
-   case 2: adj = "nimbler";		p->dex_max++;	break;
-   case 3: adj = "smarter";		p->int_max++;	break;
-   case 4: adj = "more perceptive";	p->per_max++;	break;
-  }
-  if (!p->is_npc())
-   g->add_msg("You feel %s.", adj.c_str());
+  g->add_msg("You feel cleansed.");
   return;
  }
  int num_cured = rng(1, valid.size());
@@ -616,7 +618,7 @@ void iuse::sew(game *g, player *p, item *it, bool t)
 {
  char ch = g->inv("Repair what?");
  item* fix = &(p->i_at(ch));
- if (fix->type->id == 0) {
+ if (fix == NULL || fix->is_null()) {
   g->add_msg("You do not have that item!");
   it->charges++;
   return;
@@ -714,7 +716,7 @@ void iuse::scissors(game *g, player *p, item *it, bool t)
  if (cut->type->id == itm_string_36) {
   p->moves -= 150;
   g->add_msg("You cut the string into 6 smaller pieces.");
-  item string(g->itypes[itm_string_6], g->turn, g->nextinv);
+  item string(g->itypes[itm_string_6], int(g->turn), g->nextinv);
   p->i_rem(ch);
   bool drop = false;
   for (int i = 0; i < 6; i++) {
@@ -731,6 +733,7 @@ void iuse::scissors(game *g, player *p, item *it, bool t)
    else
     p->i_add(string);
   }
+  return;
  }
  if (!cut->made_of(COTTON)) {
   g->add_msg("You can only slice items made of cotton.");
@@ -752,7 +755,7 @@ void iuse::scissors(game *g, player *p, item *it, bool t)
  }
  g->add_msg("You slice the %s into %d rag%s.", cut->tname().c_str(), count,
             (count == 1 ? "" : "s"));
- item rag(g->itypes[itm_rag], g->turn, g->nextinv);
+ item rag(g->itypes[itm_rag], int(g->turn), g->nextinv);
  p->i_rem(ch);
  bool drop = false;
  for (int i = 0; i < count; i++) {
@@ -876,12 +879,12 @@ void iuse::hammer(game *g, player *p, item *it, bool t)
  }
  nc_color col;
  mvwprintz(w, 1, 1, c_white, title.c_str());
- col = (p->has_amount(itm_nail, nails) ? c_green : c_red);
+ col = (p->has_charges(itm_nail, nails) ? c_green : c_red);
  mvwprintz(w, 2, 1, col, "> %d nails", nails);
  col = (p->has_amount(itm_2x4, boards) ? c_green : c_red);
  mvwprintz(w, 3, 1, col, "> %d two by fours", boards);
 
- if (p->has_amount(itm_nail, nails) && p->has_amount(itm_2x4, boards)) {
+ if (p->has_charges(itm_nail, nails) && p->has_amount(itm_2x4, boards)) {
   mvwprintz(w, 5, 1, c_yellow, "Perform action? (y/n)");
   wrefresh(w);
   char ch;
@@ -890,8 +893,8 @@ void iuse::hammer(game *g, player *p, item *it, bool t)
   while (ch != 'y' && ch != 'Y' && ch != 'n' && ch != 'N');
   if (ch == 'y' || ch == 'Y') {
    p->moves -= boards * 50;
-   p->use_up(itm_nail, nails);
-   p->use_up(itm_2x4, boards);
+   p->use_charges(itm_nail, nails);
+   p->use_amount(itm_2x4, boards);
    g->m.ter(dirx, diry) = newter;
   }
  } else {
@@ -983,7 +986,7 @@ void iuse::two_way_radio(game *g, player *p, item *it, bool t)
   bonus += fac->respects_u + 3 * fac->likes_u;
   if (bonus >= 25) {
    popup("They reply, \"Help is on the way!\"");
-   g->add_event(EVENT_HELP, g->turn + fac->response_time(g), fac->id, -1, -1);
+   g->add_event(EVENT_HELP, int(g->turn) + fac->response_time(g), fac->id, -1, -1);
    fac->respects_u -= rng(0, 8);
    fac->likes_u -= rng(3, 5);
   } else if (bonus >= -5) {
@@ -1113,6 +1116,8 @@ void iuse::makemound(game *g, player *p, item *it, bool t)
 
 void iuse::dig(game *g, player *p, item *it, bool t)
 {
+ g->add_msg("You can dig a pit via the construction menu--hit *");
+/*
  int dirx, diry;
  g->draw();
  mvprintw(0, 0, "Dig where?");
@@ -1130,6 +1135,7 @@ void iuse::dig(game *g, player *p, item *it, bool t)
  } else
   g->add_msg("You can't dig through %s!",
              g->m.tername(p->posx + dirx, p->posy + diry).c_str());
+*/
 }
 
 void iuse::chainsaw_off(game *g, player *p, item *it, bool t)
@@ -1295,7 +1301,7 @@ That trap needs a 3x3 space to be clear, centered two tiles from you.");
    }
   }
  }
- p->i_rem(it->invlet);
+ it->invlet = 0; // Remove the trap from the player's inv
 }
 
 void iuse::geiger(game *g, player *p, item *it, bool t)
@@ -1331,7 +1337,7 @@ void iuse::geiger(game *g, player *p, item *it, bool t)
   return;
  }
  std::string toggle_text = "Turn continuous scan ";
- toggle_text += (is_on ? "on" : "off");
+ toggle_text += (is_on ? "off" : "on");
  int ch = menu("Geiger counter:", "Scan yourself", "Scan the ground",
                toggle_text.c_str(), "Cancel", NULL);
  switch (ch) {
@@ -1381,15 +1387,15 @@ void iuse::can_goo(game *g, player *p, item *it, bool t)
   g->z.push_back(goo);
  }
  tries = 0;
- while (!one_in(5) && tries < 10) {
+ while (!one_in(4) && tries < 10) {
   tries = 0;
   do {
    goox = p->posx + rng(-2, 2);
    gooy = p->posy + rng(-2, 2);
    tries++;
   } while (g->m.move_cost(goox, gooy) == 0 &&
-           g->m.tr_at(goox, gooy) != tr_null && tries < 10);
-  if (g->m.tr_at(goox, gooy) == tr_null) {
+           g->m.tr_at(goox, gooy) == tr_null && tries < 10);
+  if (tries < 10) {
    if (g->u_see(goox, gooy, junk))
     g->add_msg("A nearby splatter of goo forms into a goo pit.");
    g->m.tr_at(goox, gooy) = tr_goo;
@@ -1399,11 +1405,11 @@ void iuse::can_goo(game *g, player *p, item *it, bool t)
 
 void iuse::pipebomb(game *g, player *p, item *it, bool t)
 {
- if (!p->has_amount(itm_lighter, 1)) {
+ if (!p->has_charges(itm_lighter, 1)) {
   g->add_msg("You need a lighter!");
   return;
  }
- p->use_up(itm_lighter, 1);
+ p->use_charges(itm_lighter, 1);
  g->add_msg("You light the fuse on the pipe bomb.");
  it->make(g->itypes[itm_pipebomb_act]);
  it->charges = 3;
@@ -1531,22 +1537,22 @@ void iuse::smokebomb_act(game *g, player *p, item *it, bool t)
 
 void iuse::molotov(game *g, player *p, item *it, bool t)
 {
- if (!p->has_amount(itm_lighter, 1)) {
+ if (!p->has_charges(itm_lighter, 1)) {
   g->add_msg("You need a lighter!");
   return;
  }
- p->use_up(itm_lighter, 1);
+ p->use_charges(itm_lighter, 1);
  g->add_msg("You light the molotov cocktail.");
  p->moves -= 150;
  it->make(g->itypes[itm_molotov_lit]);
  it->charges = 1;
- it->bday = g->turn;
+ it->bday = int(g->turn);
  it->active = true;
 }
  
 void iuse::molotov_lit(game *g, player *p, item *it, bool t)
 {
- int age = g->turn - it->bday;
+ int age = int(g->turn) - it->bday;
  if (!p->has_item(it)) {
   point pos = g->find_item(it);
   it->charges = 0;
@@ -1563,11 +1569,11 @@ void iuse::molotov_lit(game *g, player *p, item *it, bool t)
 
 void iuse::dynamite(game *g, player *p, item *it, bool t)
 {
- if (!p->has_amount(itm_lighter, 1)) {
+ if (!p->has_charges(itm_lighter, 1)) {
   g->add_msg("You need a lighter!");
   return;
  }
- p->use_up(itm_lighter, 1);
+ p->use_charges(itm_lighter, 1);
  g->add_msg("You light the dynamite.");
  it->make(g->itypes[itm_dynamite_act]);
  it->charges = 20;
@@ -1615,7 +1621,8 @@ void iuse::mininuke_act(game *g, player *p, item *it, bool t)
 
 void iuse::pheromone(game *g, player *p, item *it, bool t)
 {
- point pos = g->find_item(it);
+ point pos(p->posx, p->posy);
+
  int junk;
  bool is_u = !p->is_npc(), can_see = (is_u || g->u_see(p->posx, p->posy, junk));
  if (pos.x == -999 || pos.y == -999)
@@ -1670,7 +1677,7 @@ void iuse::manhack(game *g, player *p, item *it, bool t)
  }
  int index = rng(0, valid.size() - 1);
  p->moves -= 60;
- p->i_rem(it->invlet);	// Remove the manhack from the player's inv
+ it->invlet = 0; // Remove the manhack from the player's inv
  monster manhack(g->mtypes[mon_manhack], valid[index].x, valid[index].y);
  if (rng(0, p->int_cur / 2) + p->sklevel[sk_electronics] / 2 +
      p->sklevel[sk_computer] < rng(0, 4))
@@ -1697,7 +1704,7 @@ void iuse::turret(game *g, player *p, item *it, bool t)
   g->add_msg("You cannot place a turret there.");
   return;
  }
- p->i_rem(it->invlet);	// Remove the turret from the player's inv
+ it->invlet = 0; // Remove the turret from the player's inv
  monster turret(g->mtypes[mon_turret], dirx, diry);
  if (rng(0, p->int_cur / 2) + p->sklevel[sk_electronics] / 2 +
      p->sklevel[sk_computer] < rng(0, 6))
@@ -1818,7 +1825,7 @@ void iuse::mp3_on(game *g, player *p, item *it, bool t)
  if (t) {	// Normal use
   p->add_morale(MORALE_MUSIC, 1, 50);
 
-  if (g->turn % 10 == 0) {	// Every 10 turns, describe the music
+  if (int(g->turn) % 10 == 0) {	// Every 10 turns, describe the music
    std::string sound = "";
    switch (rng(1, 10)) {
     case 1: sound = "a sweet guitar solo!";	p->stim++;	break;
@@ -1839,6 +1846,35 @@ void iuse::mp3_on(game *g, player *p, item *it, bool t)
  }
 }
 
+void iuse::vortex(game *g, player *p, item *it, bool t)
+{
+ std::vector<point> spawn;
+ for (int i = -3; i <= 3; i++) {
+  if (g->is_empty(p->posx - 3, p->posy + i))
+   spawn.push_back( point(p->posx - 3, p->posy + i) );
+  if (g->is_empty(p->posx + 3, p->posy + i))
+   spawn.push_back( point(p->posx + 3, p->posy + i) );
+  if (g->is_empty(p->posx + i, p->posy - 3))
+   spawn.push_back( point(p->posx + i, p->posy - 3) );
+  if (g->is_empty(p->posx + i, p->posy + 3))
+   spawn.push_back( point(p->posx + i, p->posy + 3) );
+ }
+ if (spawn.empty()) {
+  if (!p->is_npc())
+   g->add_msg("Air swirls around you for a moment.");
+  it->make(g->itypes[itm_spiral_stone]);
+  return;
+ }
+
+ g->add_msg("Air swirls all over...");
+ int index = rng(0, spawn.size() - 1);
+ p->moves -= 100;
+ it->make(g->itypes[itm_spiral_stone]);
+ monster vortex(g->mtypes[mon_vortex], spawn[index].x, spawn[index].y);
+ vortex.friendly = -1;
+ g->z.push_back(vortex);
+}
+
 /* MACGUFFIN FUNCTIONS
  * These functions should refer to it->associated_mission for the particulars
  */
