@@ -17,10 +17,6 @@ long input()
   case KEY_DOWN:
   case '2': return 'j';
   case '3': return 'n';
-  //Maemo: '\n'=13, but what os 343? Maybe '\r\n'?
-  case 343: return '\n';
-  //end of maemo
-  
   default:  return ch;
  }
 }
