@@ -148,6 +148,9 @@ point map::random_outdoor_tile()
 bool map::bash(int x, int y, int str, std::string &sound)
 {
  sound = "";
+ if (field_at(x, y).type == fd_web)
+  field_at(x, y).type == fd_null;
+
  for (int i = 0; i < i_at(x, y).size(); i++) {	// Destroy glass items (maybe)
   if (i_at(x, y)[i].made_of(GLASS) && one_in(2)) {
    if (sound == "")
@@ -161,6 +164,19 @@ bool map::bash(int x, int y, int str, std::string &sound)
   }
  }
  switch (ter(x, y)) {
+ case t_wall_wood:
+  if (str >= rng(0, 120)) {
+   sound += "crash!";
+   ter(x, y) = t_dirt;
+   int num_boards = rng(8, 20);
+   for (int i = 0; i < num_boards; i++)
+    add_item(x, y, (*itypes)[itm_2x4], 0);
+   return true;
+  } else {
+   sound += "whump!";
+   return true;
+  }
+  break;
  case t_door_c:
  case t_door_locked:
  case t_door_locked_alarm:
@@ -360,6 +376,7 @@ void map::destroy(game *g, int x, int y, bool makesound)
      add_item(i, j, g->itypes[itm_2x4], 0);
    }
   }
+  break;
  case t_wall_v:
  case t_wall_h:
   for (int i = x - 2; i <= x + 2; i++) {
@@ -383,12 +400,10 @@ void map::destroy(game *g, int x, int y, bool makesound)
 
 void map::shoot(game *g, int x, int y, int &dam, bool hit_items, unsigned flags)
 {
- if (flags & mfb(IF_AMMO_FLAME) && has_flag(flammable, x, y))
-  add_field(g, x, y, fd_fire, 2);
 
  if (has_flag(alarmed, x, y) && !g->event_queued(EVENT_WANTED)) {
   g->sound(g->u.posx, g->u.posy, 30, "An alarm sounds!");
-  g->add_event(EVENT_WANTED, g->turn + 300, 0, g->levx, g->levy);
+  g->add_event(EVENT_WANTED, int(g->turn) + 300, 0, g->levx, g->levy);
  }
 
  switch (ter(x, y)) {
@@ -519,6 +534,56 @@ void map::shoot(game *g, int x, int y, int &dam, bool hit_items, unsigned flags)
  }
 }
 
+bool map::hit_with_acid(game *g, int x, int y)
+{
+ if (move_cost(x, y) != 0)
+  return false; // Didn't hit the tile!
+
+ switch (ter(x, y)) {
+  case t_wall_glass_v:
+  case t_wall_glass_h:
+  case t_wall_glass_v_alarm:
+  case t_wall_glass_h_alarm:
+  case t_vat:
+   ter(x, y) = t_floor;
+   break;
+
+  case t_door_c:
+  case t_door_locked:
+  case t_door_locked_alarm:
+   if (one_in(3))
+    ter(x, y) = t_door_b;
+   break;
+
+  case t_door_b:
+   if (one_in(4))
+    ter(x, y) = t_door_frame;
+   else
+    return false;
+   break;
+
+  case t_window:
+  case t_window_alarm:
+   ter(x, y) = t_window_empty;
+   break;
+
+  case t_wax:
+   ter(x, y) = t_floor_wax;
+   break;
+
+  case t_toilet:
+  case t_gas_pump:
+  case t_gas_pump_smashed:
+   return false;
+
+  case t_card_reader:
+   ter(x, y) = t_card_reader_broken;
+   break;
+ }
+
+ return true;
+}
+
 void map::marlossify(int x, int y)
 {
  int type = rng(1, 9);
@@ -706,7 +771,7 @@ void map::process_active_items(game *g)
     if (i_at(i, j)[n].active) {
      tmp = dynamic_cast<it_tool*>(i_at(i, j)[n].type);
      (use.*tmp->use)(g, &(g->u), &i_at(i, j)[n], true);
-     if (tmp->turns_per_charge > 0 && g->turn % tmp->turns_per_charge == 0)
+     if (tmp->turns_per_charge > 0 && int(g->turn) % tmp->turns_per_charge == 0)
       i_at(i, j)[n].charges--;
      if (i_at(i, j)[n].charges <= 0) {
       (use.*tmp->use)(g, &(g->u), &i_at(i, j)[n], false);
@@ -721,6 +786,81 @@ void map::process_active_items(game *g)
   }
  }
 }
+
+void map::use_amount(point origin, int range, itype_id type, int quantity)
+{
+ for (int radius = 0; radius <= range && quantity > 0; radius++) {
+  for (int x = origin.x - radius; x <= origin.x + radius; x++) {
+   for (int y = origin.y - radius; y <= origin.y + radius; y++) {
+    if (rl_dist(origin.x, origin.y, x, y) < radius)
+     y++; // Skip over already-examined tiles
+    else {
+     for (int n = 0; n < i_at(x, y).size() && quantity > 0; n++) {
+      item* curit = &(i_at(x, y)[n]);
+      for (int m = 0; m < curit->contents.size(); m++) {
+       if (curit->contents[m].type->id == type) {
+        curit->contents.erase(curit->contents.begin() + m);
+        m--;
+       }
+      }
+      if (curit->type->id == type) {
+       quantity--;
+       i_rem(x, y, n);
+       n--;
+      }
+     }
+    }
+   }
+  }
+ }
+}
+
+void map::use_charges(point origin, int range, itype_id type, int quantity)
+{
+ for (int radius = 0; radius <= range && quantity > 0; radius++) {
+  for (int x = origin.x - radius; x <= origin.x + radius; x++) {
+   for (int y = origin.y - radius; y <= origin.y + radius; y++) {
+    if (rl_dist(origin.x, origin.y, x, y) < radius)
+     y++; // Skip over already-examined tiles
+    else {
+     for (int n = 0; n < i_at(x, y).size(); n++) {
+      item* curit = &(i_at(x, y)[n]);
+// Check contents first
+      for (int m = 0; m < curit->contents.size() && quantity > 0; m++) {
+       if (curit->contents[m].type->id == type) {
+        if (curit->contents[m].charges < quantity) {
+         quantity -= curit->contents[m].charges;
+         if (curit->contents[m].destroyed_at_zero_charges()) {
+          curit->contents.erase(curit->contents.begin() + m);
+          m--;
+         } else
+          curit->contents[m].charges = 0;
+        } else {
+         curit->contents[m].charges -= quantity;
+         return;
+        }
+       }
+      }
+// Now check the actual item
+      if (curit->type->id == type) {
+       if (curit->charges < quantity) {
+        quantity -= curit->charges;
+        if (curit->destroyed_at_zero_charges()) {
+         i_rem(x, y, n);
+         n--;
+        } else
+         curit->charges = 0;
+       } else {
+        curit->charges -= quantity;
+        return;
+       }
+      }
+     }
+    }
+   }
+  }
+ }
+}
  
 trap_id& map::tr_at(int x, int y)
 {
@@ -787,7 +927,9 @@ field& map::field_at(int x, int y)
 
 bool map::add_field(game *g, int x, int y, field_id t, unsigned char density)
 {
- if (!field_at(x, y).is_null()) // Blood & bile are null too
+ if (field_at(x, y).type == fd_web && t == fd_fire)
+  density++;
+ else if (!field_at(x, y).is_null()) // Blood & bile are null too
   return false;
  if (density > 3)
   density = 3;
@@ -1139,7 +1281,7 @@ void map::saven(overmap *om, unsigned int turn, int worldx, int worldy,
  int n = gridx + gridy * 3;
 // Open appropriate file.
  char buff[32];
- sprintf(buff, "/home/user/.cataclysm/tmp/m.%d.%d.%d", om->posx * OMAPX * 2 + worldx + gridx,
+ sprintf(buff, "/home/user/.cataclysm/save/m.%d.%d.%d", om->posx * OMAPX * 2 + worldx + gridx,
                                   om->posy * OMAPY * 2 + worldy + gridy,
                                   om->posz);
  std::ofstream fout;
@@ -1150,7 +1292,7 @@ void map::saven(overmap *om, unsigned int turn, int worldx, int worldy,
 // Dump the terrain. Add 33 to ter to get a human-readable number or symbol.
  for (int j = 0; j < SEEY; j++) {
   for (int i = 0; i < SEEX; i++)
-   fout << char(int(grid[n].ter[i][j]) + 32);
+   fout << int(grid[n].ter[i][j]) << " ";
   fout << std::endl;
  }
 // Dump the radiation
@@ -1227,7 +1369,7 @@ bool map::loadn(game *g, int worldx, int worldy, int gridx, int gridy)
  std::string databuff;
  grid[gridn].comp = computer();
 
- sprintf(fname, "/home/user/.cataclysm/tmp/m.%d.%d.%d", g->cur_om.posx * OMAPX * 2 + worldx + gridx,
+ sprintf(fname, "/home/user/.cataclysm/save/m.%d.%d.%d", g->cur_om.posx * OMAPX * 2 + worldx + gridx,
                                    g->cur_om.posy * OMAPY * 2 + worldy + gridy,
                                    g->cur_om.posz);
  mapin.open(fname);
@@ -1235,13 +1377,14 @@ bool map::loadn(game *g, int worldx, int worldy, int gridx, int gridy)
 // Load turn number
   mapin >> old_turn;
 // Turns since last visited
-  int turndif = (g->turn > old_turn ? g->turn - old_turn : 0);
+  int turndif = (int(g->turn) > old_turn ? int(g->turn) - old_turn : 0);
   mapin.getline(line, 1);
 // Load terrain
   for (int j = 0; j < SEEY; j++) {
-   mapin.getline(line, SEEX + 1);
    for (int i = 0; i < SEEX; i++) {
-    grid[gridn].ter[i][j] = ter_id(line[i]-32);
+    int tmpter;
+    mapin >> tmpter;
+    grid[gridn].ter[i][j] = ter_id(tmpter);
     grid[gridn].itm[i][j].clear();
     grid[gridn].trp[i][j] = tr_null;
     grid[gridn].fld[i][j] = field();
@@ -1310,7 +1453,7 @@ bool map::loadn(game *g, int worldx, int worldy, int gridx, int gridy)
    newmapy = worldy + gridy;
   if (worldx + gridx < 0)
    newmapx = worldx + gridx;
-  tmp_map.generate(g, &(g->cur_om), newmapx, newmapy, g->turn);
+  tmp_map.generate(g, &(g->cur_om), newmapx, newmapy, int(g->turn));
   mapin.close();
   return false;
  }
@@ -1332,10 +1475,13 @@ void map::spawn_monsters(game *g)
      tmp.spawnposy = my;
      tmp.spawnmapx = g->levx;
      tmp.spawnmapy = g->levy;
+// TODO: this is a hacky hacky hack
+     if (tmp.type->id == mon_dog_thing)
+      tmp.friendly = -1;
      int fx = mx + gx * SEEX, fy = my + gy * SEEY;
 
-     while ((!g->is_empty(fx, fy) || !tmp.can_move_to(g->m, fx, fy) ||
-             sees(g->u.posx, g->u.posy, fx, fy, SEEX, t)) && tries < 10) {
+     while ((!g->is_empty(fx, fy) || !tmp.can_move_to(g->m, fx, fy)) && 
+            tries < 10) {
       mx = grid[n].spawns[i].posx + rng(-3, 3);
       my = grid[n].spawns[i].posy + rng(-3, 3);
       fx = mx + gx * SEEX;
