@@ -61,7 +61,7 @@ enum ter_id {
 t_null = 0,
 t_hole,	// Real nothingness; makes you fall a z-level
 // Ground
-t_dirt, t_dirtmound, t_pit,
+t_dirt, t_dirtmound, t_pit_shallow, t_pit,
 t_rock_floor, t_rubble, t_wreckage,
 t_grass,
 t_metal_floor,
@@ -69,7 +69,9 @@ t_pavement, t_pavement_y, t_sidewalk,
 t_floor,
 t_grate,
 t_slime,
+t_bridge,
 // Walls & doors
+t_wall_half, t_wall_wood,
 t_wall_v, t_wall_h,
 t_wall_metal_v, t_wall_metal_h,
 t_wall_glass_v, t_wall_glass_h,
@@ -81,8 +83,8 @@ t_door_c, t_door_b, t_door_o, t_door_locked, t_door_locked_alarm, t_door_frame,
 t_door_metal_c, t_door_metal_o, t_door_metal_locked,
 t_bulletin,
 t_portcullis,
-t_window, t_window_alarm, t_window_frame, t_window_boarded,
-t_rock,
+t_window, t_window_alarm, t_window_empty, t_window_frame, t_window_boarded,
+t_rock, t_fault,
 t_paper,
 // Tree
 t_tree, t_tree_young, t_underbrush,
@@ -103,6 +105,7 @@ t_missile, t_missile_exploded,
 t_counter,
 t_radio_tower, t_radio_controls,
 t_console_broken, t_console,
+t_sewage_pipe, t_sewage_pump,
 // Containers
 t_fridge, t_dresser,
 t_rack, t_bookcase,
@@ -110,9 +113,11 @@ t_dumpster,
 t_vat,
 // Staircases etc.
 t_stairs_down, t_stairs_up, t_manhole, t_ladder, t_slope_down, t_slope_up,
+ t_rope_up,
 t_manhole_cover,
 // Special
-t_card_reader, t_card_reader_broken, t_slot_machine,
+t_card_reader, t_card_reader_broken, t_slot_machine, t_elevator_control,
+ t_elevator_control_off, t_elevator, t_pedestal_wyrm,
 num_terrain_types
 };
 
@@ -125,7 +130,9 @@ const ter_t terlist[num_terrain_types] = {  // MUST match enum ter_id above!
 	mfb(transparent)|mfb(diggable)},
 {"mound of dirt",    '#', c_brown,   3,
 	mfb(transparent)|mfb(diggable)},
-{"shallow pit",	     '0', c_brown,  14,
+{"shallow pit",	     '0', c_yellow,  8,
+	mfb(transparent)|mfb(diggable)},
+{"pit",              '0', c_brown,  10,
 	mfb(transparent)|mfb(diggable)},
 {"rock floor",       '.', c_ltgray,  2,
 	mfb(transparent)},
@@ -149,6 +156,12 @@ const ter_t terlist[num_terrain_types] = {  // MUST match enum ter_id above!
 	mfb(transparent)},
 {"slime",            '~', c_green,   6,
 	mfb(transparent)|mfb(container)|mfb(flammable)},
+{"walkway",          '#', c_yellow,  2,
+	mfb(transparent)},
+{"half-built wall",  '#', c_brown,   4,
+	mfb(transparent)|mfb(bashable)|mfb(flammable)|mfb(noitem)},
+{"wooden wall",      '#', c_brown,   0,
+	mfb(bashable)|mfb(flammable)|mfb(noitem)},
 {"wall",             '|', c_ltgray,  0,
 	mfb(flammable)|mfb(noitem)},
 {"wall",             '-', c_ltgray,  0,
@@ -199,12 +212,16 @@ const ter_t terlist[num_terrain_types] = {  // MUST match enum ter_id above!
 	mfb(transparent)|mfb(bashable)|mfb(flammable)|mfb(noitem)},
 {"window",	     '"', c_ltcyan,  0, // Actually alarmed
 	mfb(transparent)|mfb(bashable)|mfb(flammable)|mfb(alarmed)|mfb(noitem)},
+{"empty window",     '0', c_yellow,  8,
+	mfb(transparent)|mfb(flammable)|mfb(noitem)},
 {"window frame",     '0', c_ltcyan,  8,
-	mfb(container)|mfb(transparent)|mfb(sharp)|mfb(flammable)|mfb(noitem)},
+	mfb(transparent)|mfb(sharp)|mfb(flammable)|mfb(noitem)},
 {"boarded up window",'#', c_brown,   0,
 	mfb(bashable)|mfb(flammable)|mfb(noitem)},
 {"solid rock",       '#', c_white,   0,
 	mfb(noitem)},
+{"odd fault",        '#', c_magenta, 0,
+	mfb(noitem)},
 {"paper wall",       '#', c_white,   0,
 	mfb(bashable)|mfb(flammable)|mfb(noitem)},
 {"tree",	     '7', c_green,   0,
@@ -274,16 +291,20 @@ const ter_t terlist[num_terrain_types] = {  // MUST match enum ter_id above!
 	mfb(transparent)|mfb(bashable)|mfb(noitem)},
 {"broken console",   '6', c_ltgray,  0,
 	mfb(transparent)|mfb(noitem)},
-{"computer console",  '6', c_blue,    0,
+{"computer console", '6', c_blue,    0,
 	mfb(transparent)|mfb(console)|mfb(noitem)},
-{"refrigerator",     '{', c_ltcyan,   0,
+{"sewage pipe",      '1', c_ltgray,  0,
+	mfb(transparent)},
+{"sewage pump",      '&', c_ltgray,  0,
+	mfb(noitem)},
+{"refrigerator",     '{', c_ltcyan,  0,
 	mfb(container)},
 {"dresser",          '{', c_brown,   0,
 	mfb(transparent)|mfb(container)|mfb(flammable)},
 {"display rack",     '{', c_ltgray,  0,
         mfb(transparent)|mfb(container)},
 {"book case",        '{', c_brown,   0,
-	mfb(container)|mfb(flammable)|mfb(bashable)},
+	mfb(container)|mfb(flammable)},
 {"dumpster",	     '{', c_green,   0,
 	mfb(container)},
 {"cloning vat",      '0', c_ltcyan,  0,
@@ -300,14 +321,24 @@ const ter_t terlist[num_terrain_types] = {  // MUST match enum ter_id above!
 	mfb(transparent)|mfb(goes_down)|mfb(container)},
 {"upward slope",     '<', c_brown,   2,
 	mfb(transparent)|mfb(goes_up)|mfb(container)},
-{"manhole cover",    '0',  c_dkgray, 2,
+{"rope leading up",  '<', c_white,   2,
+	mfb(transparent)|mfb(goes_up)},
+{"manhole cover",    '0', c_dkgray,  2,
 	mfb(transparent)},
 {"card reader",	     '6', c_pink,    0,
 	mfb(noitem)},
-{"broken card reader",'6', c_ltgray, 0,
+{"broken card reader",'6',c_ltgray,  0,
 	mfb(noitem)},
 {"slot machine",     '6', c_green,   0,
-	mfb(bashable)|mfb(noitem)}
+	mfb(bashable)|mfb(noitem)},
+{"elevator controls",'6', c_ltblue,  0,
+	mfb(noitem)},
+{"powerless controls",'6',c_ltgray,  0,
+	mfb(noitem)},
+{"elevator",         '.', c_magenta,  2,
+	0},
+{"dark pedestal",    '&', c_dkgray,  0,
+	mfb(transparent)}
 };
 
 enum map_extra {
@@ -357,11 +388,13 @@ enum field_id {
  fd_null = 0,
  fd_blood,
  fd_bile,
+ fd_web,
  fd_slime,
  fd_acid,
  fd_fire,
  fd_smoke,
  fd_tear_gas,
+ fd_toxic_gas,
  fd_nuke_gas,
  fd_electricity,
  fd_fatigue,
@@ -375,6 +408,8 @@ const field_t fieldlist[] = {
  {c_red, c_red, c_red},		{true, true, true}, {false, false, false},2500},
 {{"bile splatter", "bile stain", "puddle of bile"},	'%',
  {c_pink, c_pink, c_pink},	{true, true, true}, {false, false, false},2500},
+{{"cobwebs","webs", "thick webs"},			'}',
+ {c_white, c_white, c_white},	{true, true, false},{false, false, false},   0},
 {{"slime trail", "slime stain", "puddle of slime"},	'%',
  {c_ltgreen, c_ltgreen, c_green},{true, true, true},{false, false, false},2500},
 {{"acid splatter", "acid streak", "pool of acid"},	'5',
@@ -383,6 +418,8 @@ const field_t fieldlist[] = {
  {c_yellow, c_ltred, c_red},	{true, true, true}, {true, true, true},	  2000},
 {{"thin smoke",	"smoke", "thick smoke"},		'8',
  {c_white, c_ltgray, c_dkgray},	{true, false, false},{false, true, true},  400},
+{{"hazy cloud","toxic gas","thick toxic gas"},		'8',
+ {c_white, c_ltgreen, c_green}, {true, false, false},{false, true, true},  900},
 {{"hazy cloud","tear gas","thick tear gas"},		'8',
  {c_white, c_yellow, c_brown},	{true, false, false},{true, true, true},   600},
 {{"hazy cloud","radioactive gas", "thick radioactive gas"}, '8',
