@@ -11,6 +11,7 @@ enum items_location {
  mi_cannedfood, mi_pasta, mi_produce,
  mi_cleaning,
  mi_hardware, mi_tools, mi_bigtools, mi_mischw,
+ mi_consumer_electronics,
  mi_sports, mi_camping, mi_allsporting,
  mi_alcohol,
  mi_trash,
@@ -21,17 +22,21 @@ enum items_location {
  mi_cop_weapons, mi_cop_evidence,
  mi_office, mi_vault,
  mi_chemistry, mi_teleport, mi_goo, mi_cloning_vat, mi_dissection,
- mi_hydro, mi_electronics, mi_monparts, mi_bionics,
+ mi_hydro, mi_electronics, mi_monparts, mi_bionics, mi_bionics_common,
  mi_weapons, mi_survival_armor, mi_survival_tools,
+ mi_sewage_plant,
+ mi_mine_storage, mi_mine_equipment,
+ mi_spiral,
  mi_radio,
  mi_subway, mi_sewer,
  mi_cavern,
+ mi_spider,
  mi_ant_food, mi_ant_egg,
 // Monster drops
  mi_bugs, mi_bees, mi_wasps, mi_robots,
 // Map Extras
  mi_helicopter, mi_military, mi_science, mi_rare, mi_stash_food, mi_stash_ammo,
- mi_stash_wood, mi_stash_drugs,
+ mi_stash_wood, mi_stash_drugs, mi_wreckage,
 // Shopkeeps &c
  mi_trader_avoid,
  num_itloc
