@@ -164,7 +164,13 @@ void game::init_mapitems()
 	itm_2x4, itm_machete, itm_boots_steel, itm_hat_hard, itm_mask_filter,
 	itm_glasses_safety, itm_bb, itm_bbgun, itm_beartrap, itm_two_way_radio,
 	itm_radio, itm_hotplate, itm_extinguisher, itm_nailgun,
-	itm_manual_mechanics, NULL);
+	itm_manual_mechanics, itm_manual_carpentry, NULL);
+
+ setvector(
+   mapitems[mi_consumer_electronics],
+        itm_amplifier, itm_antenna, itm_battery, itm_soldering_iron,
+        itm_screwdriver, itm_processor, itm_RAM, itm_mp3, itm_flashlight,
+        itm_radio, itm_hotplate, itm_receiver, itm_transponder, itm_tazer, itm_two_way_radio, NULL);
 
  setvector(
    mapitems[mi_sports],
@@ -311,12 +317,13 @@ void game::init_mapitems()
 	itm_manual_brawl, itm_manual_knives, itm_manual_mechanics,
 	itm_manual_speech, itm_manual_business, itm_manual_first_aid,
 	itm_manual_computers, itm_cookbook, itm_manual_electronics,
-	itm_manual_tailor, itm_manual_traps, NULL);
+	itm_manual_tailor, itm_manual_traps, itm_manual_carpentry, NULL);
 
  setvector(
    mapitems[mi_textbooks],
 	itm_textbook_computers, itm_textbook_electronics, itm_textbook_business,
-	itm_textbook_chemistry, itm_SICP, itm_textbook_robots, NULL);
+	itm_textbook_chemistry, itm_textbook_carpentry, itm_SICP,
+	itm_textbook_robots, NULL);
 
  setvector(
    mapitems[mi_cop_weapons],
@@ -397,6 +404,10 @@ void game::init_mapitems()
 	itm_bionics_defense, itm_bionics_medical, itm_bionics_construction,
 	itm_bionics_super, itm_bionics_ranged, NULL);
 
+ setvector(
+   mapitems[mi_bionics_common],
+	itm_bionics_battery, itm_bionics_power, itm_bionics_tools, NULL);
+
  setvector(
    mapitems[mi_weapons],
 	itm_chain, itm_hammer, itm_wrench, itm_hammer_sledge, itm_hatchet,
@@ -419,6 +430,31 @@ void game::init_mapitems()
 	itm_chainsaw_off, itm_beartrap, itm_grenade, itm_EMPbomb, itm_hotplate,
 	itm_UPS_off, NULL);
 
+ setvector(
+   mapitems[mi_sewage_plant],
+	itm_1st_aid, itm_motor, itm_hose, itm_screwdriver, itm_wrench, itm_pipe,
+	itm_boots, itm_jumpsuit, itm_coat_lab, itm_gloves_rubber,
+	itm_mask_filter, itm_glasses_safety, itm_hat_hard, itm_extinguisher,
+	itm_flashlight, itm_water_purifier, itm_two_way_radio,
+	itm_bionics_tools, itm_bionics_hazmat, NULL);
+
+ setvector(
+   mapitems[mi_mine_storage],
+	itm_rock, itm_coal, NULL);
+
+ setvector(
+   mapitems[mi_mine_equipment],
+	itm_water, itm_1st_aid, itm_rope_30, itm_chain, itm_boots_steel,
+	itm_jumpsuit, itm_gloves_leather, itm_mask_filter, itm_mask_gas,
+	itm_glasses_safety, itm_goggles_welding, itm_goggles_nv, itm_hat_hard,
+	itm_backpack, itm_battery, itm_flashlight, itm_two_way_radio,
+	itm_jackhammer, itm_dynamite, itm_UPS_off, itm_bionics_tools,
+	itm_bionics_construction, NULL);
+
+ setvector(
+   mapitems[mi_spiral],
+	itm_spiral_stone, itm_vortex_stone, NULL);
+
  setvector(
    mapitems[mi_radio],
 	itm_cola, itm_caffeine, itm_cig, itm_weed, itm_amplifier,
@@ -441,6 +477,21 @@ void game::init_mapitems()
    mapitems[mi_cavern],
 	itm_rock, itm_jackhammer, itm_flashlight, itm_dynamite, NULL);
 
+ setvector(
+   mapitems[mi_spider],
+	itm_corpse, itm_mutagen, itm_purifier, itm_meat, itm_meat_tainted,
+	itm_arm, itm_leg, itm_1st_aid, itm_codeine, itm_oxycodone, itm_weed,
+	itm_wrapper, itm_fur, itm_leather, itm_card_id, itm_rope_30, itm_stick,
+	itm_hatchet, itm_ax, itm_bee_sting, itm_chitin_piece, itm_vest,
+	itm_mask_gas, itm_goggles_nv, itm_hat_boonie, itm_helmet_riot,
+	itm_bolt_steel, itm_shot_00, itm_762_m87, itm_556, itm_556_incendiary,
+	itm_3006_incendiary, itm_762_51, itm_762_51_incendiary, itm_saiga_12,
+	itm_hk_mp5, itm_TDI, itm_savage_111f, itm_sks, itm_ak47, itm_m4a1,
+	itm_steyr_aug, itm_v29, itm_flamethrower, itm_flashlight, itm_radio,
+	itm_geiger_off, itm_teleporter, itm_canister_goo, itm_dynamite,
+	itm_mininuke, itm_bot_manhack, itm_UPS_off, itm_bionics_battery,
+	itm_bionics_tools, NULL);
+
  setvector(
    mapitems[mi_ant_food],
 	itm_meat, itm_veggy, itm_meat_tainted, itm_veggy_tainted, itm_apple,
@@ -501,8 +552,7 @@ void game::init_mapitems()
 	itm_textbook_chemistry, itm_SICP, itm_textbook_robots,
 	itm_soldering_iron, itm_geiger_off, itm_teleporter, itm_canister_goo,
 	itm_EMPbomb, itm_pheromone, itm_portal, itm_bot_manhack, itm_UPS_off,
-	itm_tazer, itm_bionics_battery, itm_bionics_power, itm_bionics_tools,
-	itm_bionics_neuro, itm_bionics_hazmat, itm_bionics_medical, NULL);
+	itm_tazer, itm_bionics_hazmat, NULL);
 
  setvector(
    mapitems[mi_rare],
@@ -532,6 +582,10 @@ void game::init_mapitems()
 	itm_pills_sleep, itm_oxycodone, itm_xanax, itm_adderall, itm_weed,
 	itm_coke, itm_meth, itm_heroin, NULL);
 
+ setvector(
+   mapitems[mi_wreckage],
+	itm_chain, itm_steel_chunk, itm_rock, NULL);
+
 // This one kind of an inverted list; what a traveling salesman will NOT carry
  setvector(
    mapitems[mi_trader_avoid],
