@@ -18,11 +18,15 @@ class mattack
   void science		(game *g, monster *z);
   void growplants	(game *g, monster *z);
   void fungus		(game *g, monster *z);
+  void fungus_sprout	(game *g, monster *z);
   void leap		(game *g, monster *z);
   void dermatik		(game *g, monster *z);
   void plant		(game *g, monster *z);
   void disappear	(game *g, monster *z);
   void formblob		(game *g, monster *z);
+  void dogthing		(game *g, monster *z);
+  void tentacle		(game *g, monster *z);
+  void vortex		(game *g, monster *z);
   void gene_sting	(game *g, monster *z);
   void stare		(game *g, monster *z);
   void fear_paralyze	(game *g, monster *z);
