@@ -19,6 +19,7 @@ enum moncat_id {
  mcat_swamp,
  mcat_lab,
  mcat_nether,
+ mcat_spiral,
  num_moncats
 };
 
@@ -27,6 +28,7 @@ struct mongroup {
  int posx, posy;
  unsigned char radius;
  unsigned int population;
+ bool dying;
  mongroup(moncat_id ptype, int pposx, int pposy, unsigned char prad,
           unsigned int ppop) {
   type = ptype;
@@ -34,6 +36,7 @@ struct mongroup {
   posy = pposy;
   radius = prad;
   population = ppop;
+  dying = false;
  }
 };
 
