@@ -37,6 +37,7 @@ class monster {
 
 // Access
  std::string name(); 		// Returns the monster's formal name
+ std::string name_with_armor(); // Name, with whatever our armor is called
  void print_info(game *g, WINDOW* w); // Prints information to w.
  char symbol();			// Just our type's symbol; no context
  void draw(WINDOW* w, int plx, int ply, bool inv);
@@ -55,6 +56,8 @@ class monster {
 			     	// Updates current pos AND our plans
  bool wander(); 		// Returns true if we have no plans
  bool can_move_to(map &m, int x, int y); // Can we move to (x, y)?
+ bool will_reach(game *g, int x, int y); // Do we have plans to get to (x, y)?
+ int  turns_to_reach(game *g, int x, int y); // How long will it take?
 
  void set_dest(int x, int y, int &t); // Go in a straight line to (x, y)
 				      // t determines WHICH Bresenham line
