@@ -62,7 +62,7 @@ mon("wolf",		'w',	c_dkgray,	MS_MEDIUM,	FLESH,
 	(mfb(MF_SEES)|mfb(MF_HEARS)|mfb(MF_SMELLS)|mfb(MF_ANIMAL)|mfb(MF_WARM)|
 	 mfb(MF_FUR)),
 //	frq dif agr spd msk mdi m## cut dge arm itm  HP special freq
-	  4,  7,  3,165, 14,  2,  3,  4,  4,  0,  0, 28,  0,
+	  4, 12,  3,165, 14,  2,  3,  4,  4,  0,  0, 28,  0,
 	&mdeath::normal,	&mattack::none, "\
 A vicious and fast pack hunter."
 );
@@ -117,7 +117,7 @@ mandibles."
 );
 
 mon("queen ant",	'a',	c_ltred,	MS_LARGE,	FLESH,
-	(mfb(MF_SMELLS)),
+	(mfb(MF_SMELLS)|mfb(MF_QUEEN)),
 //	frq dif agr spd msk mdi m## cut dge arm itm  HP special freq
 	  0, 13,  2, 60,  6,  3,  4,  4,  1, 14,-40,180, 5,
 	&mdeath::normal,	&mattack::antqueen, "\
@@ -303,7 +303,7 @@ and it dribbles a gray sludge from its mouth."
 mon("skeleton",		'Z',	c_white,	MS_MEDIUM,	STONE,
 	(mfb(MF_SEES)|mfb(MF_HEARS)|mfb(MF_HARDTOSHOOT)),
 //	frq dif agr spd msk mdi m## cut dge arm itm  HP special freq
-	  7,  8,  5, 90, 10,  1,  5,  3,  2, 30,  0, 40, 0,
+	  7,  8,  5, 90, 10,  1,  5,  3,  2, 15,  0, 40, 0,
 	&mdeath::normal,	&mattack::none, "\
 A skeleton picked clean of all but a few\n\
 rotten scraps of flesh, somehow still in\n\
@@ -408,6 +408,27 @@ A wispy spore, about the size of a fist,\n\
 wafting on the breeze."
 );
 
+mon("fungal spire",	'T',	c_ltgray,	MS_HUGE,	VEGGY,
+	mfb(MF_NOHEAD)|mfb(MF_POISON)|mfb(MF_IMMOBILE)|mfb(MF_QUEEN),
+//	frq dif agr spd msk mdi m## cut dge arm itm  HP special freq
+	  0, 40,  5,100,  0,  0,  0,  0,  0, 10,  0,300, 5,
+	&mdeath::fungus,	&mattack::fungus_sprout, "\
+An enormous fungal spire, towering 30 feet\n\
+above the ground.  It pulsates slowly,\n\
+continuously growing new defenses."
+);
+
+mon("fungal wall",	'F',	c_dkgray,	MS_HUGE,	VEGGY,
+	mfb(MF_NOHEAD)|mfb(MF_POISON)|mfb(MF_IMMOBILE),
+//	frq dif agr spd msk mdi m## cut dge arm itm  HP special freq
+	  0,  5,  0,100,  0,  0,  0,  0,  0, 10,  0, 60, 3,
+	&mdeath::disintegrate,	&mattack::fungus, "\
+A veritable wall of fungus, grown as a\n\
+natural defense by the fungal spire. It\n\
+looks very tough, and spews spores at an\n\
+alarming rate."
+);
+
 // BLOBS & SLIMES &c
 mon("blob",		'O',	c_dkgray,	MS_MEDIUM,	LIQUID,
 	(mfb(MF_SMELLS)|mfb(MF_HEARS)|mfb(MF_GOODHEARING)|mfb(MF_NOHEAD)|
@@ -567,6 +588,141 @@ threatening, but has a large ovipositor in\n\
 place of a sting."
 );
 
+
+// SPIDERS
+mon("wolf spider",	's',	c_brown,	MS_MEDIUM,	FLESH,
+	(mfb(MF_SMELLS)|mfb(MF_HEARS)|mfb(MF_VENOM)),
+//	frq dif agr spd msk mdi m## cut dge arm itm  HP special freq
+	  1, 20,  4,110, 7,   1,  1,  8,  6,  8,-70, 40, 0,
+	&mdeath::normal,	&mattack::none, "\
+A large, brown spider, which moves quickly\n\
+and aggresively."
+);
+
+mon("web spider",	's',	c_yellow,	MS_SMALL,	FLESH,
+	(mfb(MF_SMELLS)|mfb(MF_HEARS)|mfb(MF_VENOM)|mfb(MF_WEBWALK)),
+//	frq dif agr spd msk mdi m## cut dge arm itm  HP special freq
+	  1, 16,  3,120,  5,  1,  1,  7,  5,  7,-70, 35, 0,
+	&mdeath::normal,	&mattack::none, "\
+A yellow spider the size of a dog.  It lives\n\
+in webs, waiting for prey to become\n\
+entangled before pouncing and biting."
+);
+
+mon("jumping spider",	's',	c_white,	MS_SMALL,	FLESH,
+	(mfb(MF_SMELLS)|mfb(MF_HEARS)|mfb(MF_VENOM)),
+//	frq dif agr spd msk mdi m## cut dge arm itm  HP special freq
+	  2, 14,  4,100,  7,  1,  1,  4,  8,  3,-60, 30, 2,
+	&mdeath::normal,	&mattack::leap, "\
+A small, almost cute-looking spider.  It\n\
+leaps so quickly that it almost appears to\n\
+instantaneously move from one place to\n\
+another."
+);
+
+mon("trap door spider",	's',	c_blue,		MS_MEDIUM,	FLESH,
+	(mfb(MF_SMELLS)|mfb(MF_HEARS)|mfb(MF_VENOM)|mfb(MF_WEBWALK)),
+//	frq dif agr spd msk mdi m## cut dge arm itm  HP special freq
+	  1, 20,  5,110,  5,  1,  2,  7,  3,  8,-80, 70, 0,
+	&mdeath::normal,	&mattack::none, "\
+A large spider with a bulbous thorax.  It\n\
+creates a subterranean nest and lies in\n\
+wait for prey to fall in and become trapped\n\
+in its webs."
+);
+
+mon("black widow",	's',	c_dkgray,	MS_SMALL,	FLESH,
+	(mfb(MF_SMELLS)|mfb(MF_HEARS)|mfb(MF_BADVENOM)|mfb(MF_WEBWALK)),
+//	frq dif agr spd msk mdi m## cut dge arm itm  HP special freq
+	  1, 20,  3, 90,  6,  1,  1,  6,  3,  3,-50, 40, 0,
+	&mdeath::normal,	&mattack::none, "\
+A spider with a characteristic red\n\
+hourglass on its black carapace.  It is\n\
+known for its highly toxic venom."
+);
+
+// UNEARTHED HORRORS
+mon("dark wyrm",	'S',	c_blue,		MS_LARGE,	FLESH,
+	(mfb(MF_SMELLS)|mfb(MF_HEARS)|mfb(MF_GOODHEARING)|mfb(MF_DESTROYS)|
+	 mfb(MF_POISON)|mfb(MF_SUNDEATH)|mfb(MF_ACIDPROOF)|mfb(MF_ACIDTRAIL)),
+//	frq dif agr spd msk mdi m## cut dge arm itm  HP special freq
+	  1, 20,  5, 90,  8,  2,  6,  4,  4,  0,  0, 80, 0,
+	&mdeath::normal,	&mattack::none, "\
+A huge, black worm, its flesh glistening\n\
+with an acidic, blue slime.  It has a gaping\n\
+round mouth lined with dagger-like teeth."
+);
+
+mon("Amigara horror",	'H',	c_white,	MS_LARGE,	FLESH,
+	(mfb(MF_SMELLS)|mfb(MF_HEARS)|mfb(MF_SEES)|mfb(MF_STUMBLES)|
+	 mfb(MF_HARDTOSHOOT)),
+//	frq dif agr spd msk mdi m## cut dge arm itm  HP special freq
+	  1, 30,  5, 70, 10,  2,  4,  0,  2,  0,  0,250, 0,
+	&mdeath::amigara,	&mattack::fear_paralyze, "\
+A spindly body, standing at least 15 feet\n\
+tall.  It looks vaguely human, but its face is\n\
+grotesquely stretched out, and its limbs are\n\
+distorted to the point of being tentacles."
+);
+
+// This "dog" is, in fact, a disguised Thing
+mon("dog",		'd',	c_white,	MS_SMALL,	FLESH,
+	(mfb(MF_SEES)|mfb(MF_SMELLS)|mfb(MF_HEARS)|mfb(MF_ANIMAL)|mfb(MF_WARM)|
+	 mfb(MF_FUR)|mfb(MF_FRIENDLY_SPECIAL)),
+//	frq dif agr spd msk mdi m## cut dge arm itm  HP special freq
+	  3,  5,  1,150, 12,  2,  3,  3,  3,  0,  0, 25, 40,
+	&mdeath::thing,		&mattack::dogthing, "\
+A medium-sized domesticated dog, gone feral."
+);
+
+mon("tentacle dog",	'd',	c_dkgray,	MS_MEDIUM,	FLESH,
+	(mfb(MF_SEES)|mfb(MF_SMELLS)|mfb(MF_HEARS)|mfb(MF_BASHES)),
+//	frq dif agr spd msk mdi m## cut dge arm itm  HP special freq
+	  1, 14,  5,120, 12,  2,  4,  0,  3,  0,  0,120, 5,
+	&mdeath::thing,		&mattack::tentacle, "\
+A dog's body with a mass of ropy, black\n\
+tentacles extending from its head."
+);
+
+mon("Thing",		'H',	c_dkgray,	MS_LARGE,	FLESH,
+	(mfb(MF_SMELLS)|mfb(MF_HEARS)|mfb(MF_NOHEAD)|mfb(MF_BASHES)|
+	 mfb(MF_SWIMS)|mfb(MF_ATTACKMON)|mfb(MF_PLASTIC)|mfb(MF_ACIDPROOF)),
+//	frq dif agr spd msk mdi m## cut dge arm itm  HP special freq
+	  1, 25,  5,135, 14,  2,  4,  0,  5,  0,  0,160, 5,
+	&mdeath::melt,		&mattack::tentacle, "\
+An amorphous black creature which seems to\n\
+sprout tentacles rapidly."
+);
+
+mon("human snail",	'h',	c_green,	MS_LARGE,	FLESH,
+	(mfb(MF_SMELLS)|mfb(MF_HEARS)|mfb(MF_POISON)|mfb(MF_ACIDPROOF)|
+	 mfb(MF_ACIDTRAIL)),
+//	frq dif agr spd msk mdi m## cut dge arm itm  HP special freq
+	 20, 10,  3, 50,  4,  1,  5,  0,  0, 10,  0, 50, 15,
+	&mdeath::normal,	&mattack::acid, "\
+A large snail, with an oddly human face."
+);
+
+mon("twisted body",	'h',	c_pink,		MS_MEDIUM,	FLESH,
+	(mfb(MF_SEES)|mfb(MF_HEARS)|mfb(MF_GOODHEARING)|mfb(MF_POISON)),
+//	frq dif agr spd msk mdi m## cut dge arm itm  HP special freq
+	  5, 12,  5, 90,  5,  2,  4,  0,  6,  0,  0, 65, 0,
+	&mdeath::normal,	&mattack::none, "\
+A human body, but with its limbs, neck, and\n\
+hair impossibly twisted."
+);
+
+mon("vortex",		'v',	c_white,	MS_SMALL,	POWDER,
+	(mfb(MF_HEARS)|mfb(MF_GOODHEARING)|mfb(MF_STUMBLES)|mfb(MF_NOHEAD)|
+	 mfb(MF_HARDTOSHOOT)|mfb(MF_FLIES)|mfb(MF_PLASTIC)|mfb(MF_SHOCK)|
+	 mfb(MF_FRIENDLY_SPECIAL)),
+//	frq dif agr spd msk mdi m## cut dge arm itm  HP special freq
+	  2, 30,  5,120,  0,  0,  0,  0,  0,  0,  0, 20, 6,
+	&mdeath::melt,		&mattack::vortex, "\
+A twisting spot in the air, with some kind\n\
+of morphing mass at its center."
+);
+
 // NETHER WORLD INHABITANTS
 mon("flying polyp",	'H',	c_dkgray,	MS_HUGE,	FLESH,
 	(mfb(MF_SMELLS)|mfb(MF_HEARS)|mfb(MF_GOODHEARING)|mfb(MF_NOHEAD)|
@@ -637,7 +793,7 @@ through the air."
 mon("kreck",		'h',	c_ltred,	MS_SMALL,	FLESH,
 	(mfb(MF_SEES)|mfb(MF_SMELLS)|mfb(MF_HEARS)|mfb(MF_WARM)|mfb(MF_BASHES)),
 //	frq dif agr spd msk mdi m## cut dge arm itm  HP special freq
-	  9,  5,  5,135,  6,  2,  3,  4,  5,  5,  0, 35, 0,
+	  9,  5,  5,135,  6,  2,  2,  1,  5,  5,  0, 35, 0,
 	&mdeath::melt,		&mattack::none, "\
 A small humanoid, the size of a dog, with\n\
 twisted red flesh and a distended neck. It\n\
