@@ -67,8 +67,9 @@ enum dis_type {
  DI_BOOMERED, DI_SPORES, DI_FUNGUS, DI_SLIMED,
  DI_BLIND,
  DI_LYING_DOWN, DI_SLEEP,
- DI_POISON, DI_FOODPOISON, DI_SHAKES,
+ DI_POISON, DI_BADPOISON, DI_FOODPOISON, DI_SHAKES,
  DI_DERMATIK, DI_FORMICATION,
+ DI_WEBBED,
 // Food & Drugs
  DI_PKILL1, DI_PKILL2, DI_PKILL3, DI_PKILL_L, DI_DRUNK, DI_CIG, DI_HIGH,
   DI_HALLU, DI_VISUALS, DI_IODINE, DI_TOOK_XANAX, DI_TOOK_PROZAC,
@@ -76,7 +77,7 @@ enum dis_type {
 // Traps
  DI_BEARTRAP, DI_IN_PIT,
 // Other
- DI_TELEGLOW
+ DI_AMIGARA, DI_TELEGLOW
 };
 
 enum add_type {
@@ -105,7 +106,7 @@ struct addiction
 
 enum activity_type {
  ACT_NULL = 0,
- ACT_RELOAD, ACT_READ, ACT_WAIT, ACT_CRAFT, ACT_BUTCHER,
+ ACT_RELOAD, ACT_READ, ACT_WAIT, ACT_CRAFT, ACT_BUTCHER, ACT_BUILD,
  NUM_ACTIVITIES
 };
 
@@ -114,12 +115,16 @@ struct player_activity
  activity_type type;
  int moves_left;
  int index;
- player_activity() { type = ACT_NULL; moves_left = 0; index = -1; }
+ std::vector<int> values;
+ point placement;
+ player_activity() { type = ACT_NULL; moves_left = 0; index = -1;
+                     placement = point(-1, -1); }
  player_activity(activity_type t, int turns, int Index)
  {
   type = t;
   moves_left = turns;
   index = Index;
+  placement = point(-1, -1);
  }
 };
  
@@ -141,7 +146,6 @@ enum pl_flag {
  PF_DEFT,	// Less movement penalty for melee miss
  PF_DRUNKEN,	// Having a drunk status improves melee combat
  PF_GOURMAND,	// Faster eating, higher level of max satiated
- PF_SUPERTASTER,// ALWAYS warned for rotten food
  PF_ANIMALEMPATH,// Animals run away more
  PF_TERRIFYING,	// All creatures run away more
  PF_DISRESISTANT,// Less likely to succumb to low health; TODO: Implement this
@@ -251,7 +255,7 @@ you less."},
 You're a quick reader, and can get through books a lot faster than most."},
 {"Tough", 5, false, "\
 It takes a lot to bring you down!  You get a 20%% bonus to all hit points."},
-{"Thick-Skinned", 2, true, "\
+{"Thick-Skinned", 2, false, "\
 Your skin is tough.  Cutting damage is slightly reduced for you."},
 {"Packmule", 3, false, "\
 You can manage to find space for anything!  You can carry 40%% more volume."},
@@ -270,8 +274,6 @@ considerably, especially unarmed combat."},
 You eat faster, and can eat and drink more, than anyone else!  You also enjoy\n\
 food more; delicious food is better for your morale, and you don't mind some\n\
 unsavory meals."},
-{"Supertaster", 1, false, "\
-You can tell if food is even a little spoiled before eating it."},
 {"Animal Empathy", 1, false, "\
 Peaceful animals will not run away from you, and even aggressive animals are\n\
 less likely to attack.  This only applies to natural animals such as woodland\n\
@@ -305,21 +307,21 @@ mutation will be beneficial are greatly increased."},
 
 {"NULL", 0, " -------------------------------------------------- "},
 
-{"Near-Sighted", -2, true, "\
+{"Near-Sighted", -2, false, "\
 Without your glasses, your seeing radius is severely reduced!  However, while\n\
 wearing glasses this trait has no effect, and you are guaranteed to start\n\
 with a pair."},
 {"Heavy Sleeper", -1, false, "\
 You're quite the heavy sleeper.  Noises are unlikely to wake you up."},
-{"Asthmatic", -4, true, "\
+{"Asthmatic", -4, false, "\
 You will occasionally need to use an inhaler, or else suffer severe physical\n\
 limitations.  However, you are guaranteed to start with an inhaler."},
-{"Bad Back", -3, true, "\
+{"Bad Back", -3, false, "\
 You simply can not carry as much as people with a similar strength could.\n\
 Your maximum weight carried is reduced by 35%%."},
 {"Illiterate", -5, false, "\
 You never learned to read!  Books and computers are off-limits to you."},
-{"Poor Hearing", -2, true, "\
+{"Poor Hearing", -2, false, "\
 Your hearing is poor, and you may not hear quiet or far-off noises."},
 {"Insomniac", -2, false, "\
 You have a hard time falling asleep, even under the best circumstances!"},
@@ -344,7 +346,7 @@ firearms."},
 {"Smelly", -1, false, "\
 Your scent is particularly strong.  It's not offensive to humans, but animals\n\
 that track your scent will do so more easily."},
-{"Chemical Imbalance", -2, true, "\
+{"Chemical Imbalance", -2, false, "\
 You suffer from a minor chemical imbalance, whether mental or physical. Minor\n\
 changes to your internal chemistry will manifest themselves on occasion,\n\
 such as hunger, sleepiness, narcotic effects, etc."},
