@@ -7,6 +7,17 @@
 #include "skill.h"
 #include "rng.h"
 
+int time_to_fire(player &p, it_gun* firing);
+int recoil_add(player &p);
+void make_gun_sound_effect(game *g, player &p, bool burst);
+int calculate_range(player &p, int tarx, int tary);
+double calculate_missed_by(player &p, int trange);
+void shoot_monster(game *g, player &p, monster &mon, int &dam, double goodhit);
+void shoot_player(game *g, player &p, player *h, int &dam, double goodhit);
+
+void splatter(game *g, std::vector<point> trajectory, int dam,
+              monster* mon = NULL);
+
 void game::fire(player &p, int tarx, int tary, std::vector<point> &trajectory,
                 bool burst)
 {
@@ -33,36 +44,7 @@ void game::fire(player &p, int tarx, int tary, std::vector<point> &trajectory,
  int junk = 0;
  bool u_see_shooter = u_see(p.posx, p.posy, junk);
 // Use different amounts of time depending on the type of gun and our skill
- switch (firing->skill_used) {
- case (sk_pistol):
-  if (p.sklevel[sk_pistol] > 6)
-   p.moves -= 10;
-  else
-   p.moves -= (80 - 10 * p.sklevel[sk_pistol]);
-  break;
- case (sk_shotgun):
-  if (p.sklevel[sk_shotgun] > 3)
-   p.moves -= 70;
-  else
-   p.moves -= (150 - 25 * p.sklevel[sk_shotgun]);
- break;
- case (sk_smg):
-  if (p.sklevel[sk_smg] > 5)
-   p.moves -= 20;
-  else
-   p.moves -= (80 - 10 * p.sklevel[sk_smg]);
- break;
- case (sk_rifle):
-  if (p.sklevel[sk_rifle] > 8)
-   p.moves -= 30;
-  else
-   p.moves -= (150 - 15 * p.sklevel[sk_rifle]);
- break;
- default:
-  debugmsg("Why is shooting %s using %s skill?", (firing->name).c_str(),
-		skill_name(firing->skill_used).c_str());
- }
-
+ p.moves -= time_to_fire(p, firing);
 // Decide how many shots to fire
  int num_shots = 1;
  if (burst)
@@ -74,34 +56,7 @@ void game::fire(player &p, int tarx, int tary, std::vector<point> &trajectory,
   debugmsg("game::fire() - num_shots = 0!");
  
  // Make a sound at our location - Zombies will chase it
- std::string gunsound;
- int noise = p.weapon.noise();
- if (noise < 5) {
-  if (burst)
-   gunsound = "Brrrip!";
-  else
-   gunsound = "plink!";
- } else if (noise < 25) {
-  if (burst)
-   gunsound = "Brrrap!";
-  else
-   gunsound = "bang!";
- } else if (noise < 60) {
-  if (burst)
-   gunsound = "P-p-p-pow!";
-  else
-   gunsound = "blam!";
- } else {
-  if (burst)
-   gunsound = "Kaboom!!";
-  else
-   gunsound = "kerblam!";
- }
- if (p.weapon.curammo->type == AT_FUSION || p.weapon.curammo->type == AT_BATT ||
-     p.weapon.curammo->type == AT_PLUT)
-  sound(p.posx, u.posy, 8, "Fzzt!");
- else if (!is_bolt)
-  sound(p.posx, p.posy, noise, gunsound);
+ make_gun_sound_effect(this, p, burst);
 // Set up a timespec for use in the nanosleep function below
  timespec ts;
  ts.tv_sec = 0;
@@ -109,61 +64,13 @@ void game::fire(player &p, int tarx, int tary, std::vector<point> &trajectory,
 
 // Use up some ammunition
  p.weapon.charges -= num_shots;
- double deviation;
- double missed_by;
- int trange = trig_dist(p.posx, p.posy, tarx, tary);
- if (trange < int(firing->volume / 3) && firing->ammo != AT_SHOT)
-  trange = int(firing->volume / 3);
- else if (p.has_bionic(bio_targeting)) {
-  if (trange > LONG_RANGE)
-   trange = int(trange * .65);
-  else
-   trange = int(trange * .8);
- }
- if (firing->skill_used == sk_rifle && trange > LONG_RANGE)
-  trange = LONG_RANGE + .6 * (trange - LONG_RANGE);
- std::string message = "";
- bool missed;
+ bool missed = false;
  int tart;
  for (int curshot = 0; curshot < num_shots; curshot++) {
-// Calculate deviation from intended target (assuming we shoot for the head)
-  deviation = 0;
-// Up to 1.5 degrees for each skill point < 4; up to 1.25 for each point > 4
-  if (p.sklevel[firing->skill_used] < 4)
-   deviation += rng(0, 6 * (4 - p.sklevel[firing->skill_used]));
-  else
-   deviation -= rng(0, 5 * (4 - p.sklevel[firing->skill_used] - 4));
+  int trange = calculate_range(p, tarx, tary);
+  double missed_by = calculate_missed_by(p, trange);
+  p.recoil += recoil_add(p);
 
-  if (p.sklevel[sk_gun] < 3)
-   deviation += rng(0, 3 * (3 - p.sklevel[sk_gun]));
-  else
-   deviation -= rng(0, 2 * (p.sklevel[sk_gun] - 3));
-
-  deviation += p.ranged_dex_mod();
-  deviation += p.ranged_per_mod();
-
-  deviation += rng(0, 2 * p.encumb(bp_arms)) + rng(0, 4 * p.encumb(bp_eyes));
-
-  deviation += rng(0, p.weapon.curammo->accuracy);
-  deviation += rng(0, p.weapon.accuracy());
-  deviation += rng(int(p.recoil / 4), p.recoil);
-
-  int recoil_add = p.weapon.recoil();
-  recoil_add -= rng(p.str_cur / 2, p.str_cur);
-  recoil_add -= rng(0, p.sklevel[firing->skill_used] / 2);
-  if (recoil_add > 0)
-   p.recoil += recoil_add;
-
-// .013 * trange is a computationally cheap version of finding the tangent.
-// (note that .00325 * 4 = .013; .00325 is used because deviation is a number
-//  of quarter-degrees)
-// It's also generous; missed_by will be rather short.
-  missed_by = .00325 * deviation * trange;
-  missed = false;
-  if (debugmon)
-   debugmsg("\
-missed_by %f deviation %f trange %d charges %d myx %d myy %d monx %d mony %d",
-missed_by, deviation, trange, p.weapon.charges, p.posx, p.posy, tarx, tary);
   if (missed_by >= 1) {
 // We missed D:
 // Shoot a random nearby space?
@@ -206,162 +113,52 @@ missed_by, deviation, trange, p.weapon.charges, p.posx, p.posy, tarx, tary);
     nanosleep(&ts, NULL);
    }
    
-   if (dam <= 0) {
+   if (dam <= 0) { // Ran out of momentum.
     if (is_bolt &&
-        ((p.weapon.curammo->m1 == WOOD && !one_in(5)) ||
+        ((p.weapon.curammo->m1 == WOOD && !one_in(4)) ||
          (p.weapon.curammo->m1 != WOOD && !one_in(15))))
      m.add_item(trajectory[i].x, trajectory[i].y, ammotmp);
     if (p.weapon.charges == 0)
      p.weapon.curammo = NULL;
     return;
    }
-   message = "";
-   int tx = trajectory[i].x;
-   int ty = trajectory[i].y;
+
+   int tx = trajectory[i].x, ty = trajectory[i].y;
 // If there's a monster in the path of our bullet, and either our aim was true,
 //  OR it's not the monster we were aiming at and we were lucky enough to hit it
    int mondex = mon_at(tx, ty);
+// If we shot us a monster...
    if (mondex != -1 && (!z[mondex].has_flag(MF_DIGS) ||
        rl_dist(p.posx, p.posy, z[mondex].posx, z[mondex].posy) <= 1) &&
        ((!missed && i == trajectory.size() - 1) ||
-        one_in((10 - int(z[mon_at(tx, ty)].type->size))))) {
-// If we shot us a monster...
-// Calculate damage depending on how good our hit was
+        one_in((5 - int(z[mon_at(tx, ty)].type->size))))) {
+
     double goodhit = missed_by;
-    bool u_see_mon = u_see(&(z[mondex]), junk);
-    if (i < trajectory.size() - 1)
+    if (i < trajectory.size() - 1) // Unintentional hit
      goodhit = double(rand() / (RAND_MAX + 1.0)) / 2;
-    if (z[mondex].has_flag(MF_HARDTOSHOOT) && !one_in(6) &&
-        p.weapon.curammo->accuracy >= 4) { // Shot hits anyway
-     if (u_see_mon)
-      add_msg("The shot passes through the %s without hitting.",
-              z[mondex].name().c_str());
-     goodhit = 1;
-    } else {
-// Armor blocks BEFORE any critical effects.
-     int zarm = z[mondex].armor();
-     zarm -= p.weapon.curammo->pierce;
-     if (p.weapon.curammo->accuracy < 4) // Shot doesn't penetrate armor well
-      zarm *= rng(2, 4);
-     if (zarm > 0)
-      dam -= zarm;
-     if (dam < 0) {
-      if (u_see_mon)
-       add_msg("The shot reflects off the %s%s!",
-               z[mondex].name().c_str(),
-               z[mondex].made_of(FLESH) ? "'s armored hide" : "");
-      dam = 0;
-      goodhit = 1;
-     }
-     if (goodhit < .1 && !z[mondex].has_flag(MF_NOHEAD)) {
-      message = "Headshot!";
-      dam = rng(5 * dam, 8 * dam);
-      p.practice(firing->skill_used, 5);
-     } else if (goodhit < .2) {
-      message = "Critical!";
-      dam = rng(dam * 2, dam * 3);
-      p.practice(firing->skill_used, 2);
-     } else if (goodhit < .4) {
-      dam = rng(int(dam * .9), int(dam * 1.5));
-      p.practice(firing->skill_used, rng(0, 2));
-     } else if (goodhit <= .7) {
-      message = "Grazing hit.";
-      dam = rng(0, dam);
-     } else
-      dam = 0;
-// Find the zombie at (x, y) and hurt them, MAYBE kill them!
-     if (dam > 0) {
-      z[mondex].moves -= dam * 5;
-      if (&p == &u && u_see_mon)
-       add_msg("%s You hit the %s for %d damage.", message.c_str(),
-               z[mondex].name().c_str(), dam);
-      else if (u_see_mon)
-       add_msg("%s %s shoots the %s.", message.c_str(), p.name.c_str(),
-               z[mondex].name().c_str());
-      if (z[mondex].hurt(dam))
-       kill_mon(mondex);
-      else if (flags != 0)
-       hit_monster_with_flags(z[mondex], flags);
-      dam = 0;
-     }
-    }
-   } else if ((!missed || one_in(5)) && (npc_at(tx, ty) != -1 ||
-                                         (u.posx == tx && u.posy == ty)))  {
+    
+    splatter(this, trajectory, dam, &z[mondex]);
+    shoot_monster(this, p, z[mondex], dam, goodhit);
+
+
+   } else if ((!missed || one_in(3)) &&
+              (npc_at(tx, ty) != -1 || (u.posx == tx && u.posy == ty)))  {
     double goodhit = missed_by;
-    body_part hit;
+    if (i < trajectory.size() - 1) // Unintentional hit
+     goodhit = double(rand() / (RAND_MAX + 1.0)) / 2;
     player *h;
     if (u.posx == tx && u.posy == ty)
      h = &u;
     else
      h = &(active_npc[npc_at(tx, ty)]);
-    int side = rng(0, 1);
-    if (i < trajectory.size() - 1)
-     goodhit = double(rand() / (RAND_MAX + 1.0)) / 2;
-    if (goodhit < .05) {
-     hit = bp_eyes;
-     dam = rng(3 * dam, 5 * dam);
-     p.practice(firing->skill_used, 5);
-    } else if (goodhit < .1) {
-     if (one_in(6))
-      hit = bp_eyes;
-     else if (one_in(4))
-      hit = bp_mouth;
-     else
-      hit = bp_head;
-     dam = rng(2 * dam, 5 * dam);
-     p.practice(firing->skill_used, 5);
-    } else if (goodhit < .2) {
-     hit = bp_torso;
-     dam = rng(1.5 * dam, 3 * dam);
-     p.practice(firing->skill_used, 2);
-    } else if (goodhit < .4) {
-     if (one_in(3))
-      hit = bp_torso;
-     else if (one_in(2))
-      hit = bp_arms;
-     else
-      hit = bp_legs;
-     dam = rng(int(dam * .9), int(dam * 1.5));
-     p.practice(firing->skill_used, rng(0, 1));
-    } else if (goodhit < .5) {
-     if (one_in(2))
-      hit = bp_arms;
-     else
-      hit = bp_legs;
-     dam = rng(dam / 2, dam);
-    } else {
-     dam = 0;
-    }
-    if (dam > 0) {
-     if (h == &u) {
-      add_msg("%s %s shoots your %s!", message.c_str(), p.name.c_str(),
-              body_part_name(hit, side).c_str());
-     } else {
-      h->moves -= dam * 4;
-      if (hit == bp_legs)
-       h->moves -= dam * 4;
-      if (&p == &u)
-       add_msg("%s You hit %s's %s for %d damage.",
-               message.c_str(), h->name.c_str(),
-               body_part_name(hit, side).c_str(), dam);
-      else if (u_see(tx, ty, junk))
-       add_msg("%s %s shoots %s's %s for %d damage.",
-               message.c_str(), p.name.c_str(), h->name.c_str(),
-               body_part_name(hit, side).c_str(), dam);
-     }
-     h->hit(this, hit, side, 0, dam);
-     if (h != &u) {
-      int npcdex = npc_at(tx, ty);
-      if (active_npc[npcdex].hp_cur[hp_head] <= 0 ||
-          active_npc[npcdex].hp_cur[hp_torso] <= 0) {
-       active_npc[npcdex].die(this, !p.is_npc());
-       active_npc.erase(active_npc.begin() + npcdex);
-      }
-     }
-    }
+
+    splatter(this, trajectory, dam);
+    shoot_player(this, p, h, dam, missed_by);
+
    } else
     m.shoot(this, tx, ty, dam, i == trajectory.size() - 1, flags);
-  }
+  } // Done with the trajectory!
+
   if (is_bolt &&
       ((p.weapon.curammo->m1 == WOOD && !one_in(5)) ||
        (p.weapon.curammo->m1 != WOOD && !one_in(15)))) {
@@ -457,7 +254,7 @@ void game::throw_item(player &p, int tarx, int tary, item &thrown,
    if (thrown.made_of(GLASS) && !thrown.active && // active = molotov, etc.
        rng(0, thrown.volume() + 8) - rng(0, p.str_cur) < thrown.volume()) {
     if (u_see(tx, ty, tart))
-    add_msg("The %s shatters!", thrown.tname().c_str());
+     add_msg("The %s shatters!", thrown.tname().c_str());
     for (int i = 0; i < thrown.contents.size(); i++)
      m.add_item(tx, ty, thrown.contents[i]);
     sound(tx, ty, 16, "glass breaking!");
@@ -609,6 +406,7 @@ std::vector<point> game::target(int &x, int &y, int lowx, int lowy, int hix,
      }
     }
    }
+   mvwprintw(w_target, 5, 1, "Range: %d", rl_dist(u.posx, u.posy, x, y));
    if (mon_at(x, y) == -1) {
     mvwputch(w_terrain, y + SEEY - u.posy, x + SEEX - u.posx, c_red, '*');
     mvwprintw(w_status, 0, 9, "                             ");
@@ -679,3 +477,289 @@ void game::hit_monster_with_flags(monster &z, unsigned int flags)
 
  }
 }
+
+int time_to_fire(player &p, it_gun* firing)
+{
+ switch (firing->skill_used) {
+ case (sk_pistol):
+  if (p.sklevel[sk_pistol] > 6)
+   return 10;
+  else
+   return (80 - 10 * p.sklevel[sk_pistol]);
+  break;
+ case (sk_shotgun):
+  if (p.sklevel[sk_shotgun] > 3)
+   return 70;
+  else
+   return (150 - 25 * p.sklevel[sk_shotgun]);
+ break;
+ case (sk_smg):
+  if (p.sklevel[sk_smg] > 5)
+   return 20;
+  else
+   return (80 - 10 * p.sklevel[sk_smg]);
+ break;
+ case (sk_rifle):
+  if (p.sklevel[sk_rifle] > 8)
+   return 30;
+  else
+   return (150 - 15 * p.sklevel[sk_rifle]);
+ break;
+ default:
+  debugmsg("Why is shooting %s using %s skill?", (firing->name).c_str(),
+		skill_name(firing->skill_used).c_str());
+  return 0;
+ }
+ return 0;
+}
+
+void make_gun_sound_effect(game *g, player &p, bool burst)
+{
+ std::string gunsound;
+ int noise = p.weapon.noise();
+ if (noise < 5) {
+  if (burst)
+   gunsound = "Brrrip!";
+  else
+   gunsound = "plink!";
+ } else if (noise < 25) {
+  if (burst)
+   gunsound = "Brrrap!";
+  else
+   gunsound = "bang!";
+ } else if (noise < 60) {
+  if (burst)
+   gunsound = "P-p-p-pow!";
+  else
+   gunsound = "blam!";
+ } else {
+  if (burst)
+   gunsound = "Kaboom!!";
+  else
+   gunsound = "kerblam!";
+ }
+ if (p.weapon.curammo->type == AT_FUSION || p.weapon.curammo->type == AT_BATT ||
+     p.weapon.curammo->type == AT_PLUT)
+  g->sound(p.posx, p.posy, 8, "Fzzt!");
+ else if (p.weapon.curammo->type != AT_BOLT)
+  g->sound(p.posx, p.posy, noise, gunsound);
+}
+
+int calculate_range(player &p, int tarx, int tary)
+{
+ int trange = rl_dist(p.posx, p.posy, tarx, tary);
+ it_gun* firing = dynamic_cast<it_gun*>(p.weapon.type);
+ if (trange < int(firing->volume / 3) && firing->ammo != AT_SHOT)
+  trange = int(firing->volume / 3);
+ else if (p.has_bionic(bio_targeting)) {
+  if (trange > LONG_RANGE)
+   trange = int(trange * .65);
+  else
+   trange = int(trange * .8);
+ }
+
+ if (firing->skill_used == sk_rifle && trange > LONG_RANGE)
+  trange = LONG_RANGE + .6 * (trange - LONG_RANGE);
+
+ return trange;
+}
+
+double calculate_missed_by(player &p, int trange)
+{
+ it_gun* firing = dynamic_cast<it_gun*>(p.weapon.type);
+// Calculate deviation from intended target (assuming we shoot for the head)
+  double deviation = 0.; // Measured in quarter-degrees
+// Up to 1.5 degrees for each skill point < 4; up to 1.25 for each point > 4
+  if (p.sklevel[firing->skill_used] < 4)
+   deviation += rng(0, 6 * (4 - p.sklevel[firing->skill_used]));
+  else if (p.sklevel[firing->skill_used] > 4)
+   deviation -= rng(0, 5 * (p.sklevel[firing->skill_used] - 4));
+
+  if (p.sklevel[sk_gun] < 3)
+   deviation += rng(0, 3 * (3 - p.sklevel[sk_gun]));
+  else
+   deviation -= rng(0, 2 * (p.sklevel[sk_gun] - 3));
+
+  deviation += p.ranged_dex_mod();
+  deviation += p.ranged_per_mod();
+
+  deviation += rng(0, 2 * p.encumb(bp_arms)) + rng(0, 4 * p.encumb(bp_eyes));
+
+  deviation += rng(0, p.weapon.curammo->accuracy);
+  deviation += rng(0, p.weapon.accuracy());
+  deviation += rng(int(p.recoil / 4), p.recoil);
+
+// .013 * trange is a computationally cheap version of finding the tangent.
+// (note that .00325 * 4 = .013; .00325 is used because deviation is a number
+//  of quarter-degrees)
+// It's also generous; missed_by will be rather short.
+  return (.00325 * deviation * trange);
+}
+
+int recoil_add(player &p)
+{
+ it_gun* firing = dynamic_cast<it_gun*>(p.weapon.type);
+ int ret = p.weapon.recoil();
+ ret -= rng(p.str_cur / 2, p.str_cur);
+ ret -= rng(0, p.sklevel[firing->skill_used] / 2);
+ if (ret > 0)
+  return ret;
+ return 0;
+}
+
+void shoot_monster(game *g, player &p, monster &mon, int &dam, double goodhit)
+{
+ it_gun* firing = dynamic_cast<it_gun*>(p.weapon.type);
+ std::string message;
+ int junk;
+ bool u_see_mon = g->u_see(&(mon), junk);
+ if (mon.has_flag(MF_HARDTOSHOOT) && !one_in(4) &&
+     p.weapon.curammo->accuracy >= 4) { // Buckshot hits anyway
+  if (u_see_mon)
+   g->add_msg("The shot passes through the %s without hitting.",
+           mon.name().c_str());
+  goodhit = 1;
+ } else { // Not HARDTOSHOOT
+// Armor blocks BEFORE any critical effects.
+  int zarm = mon.armor();
+  zarm -= p.weapon.curammo->pierce;
+  if (p.weapon.curammo->accuracy < 4) // Shot doesn't penetrate armor well
+   zarm *= rng(2, 4);
+  if (zarm > 0)
+   dam -= zarm;
+  if (dam < 0) {
+   if (u_see_mon)
+    g->add_msg("The shot reflects off the %s!",
+            mon.name_with_armor().c_str());
+   dam = 0;
+   goodhit = 1;
+  }
+  if (goodhit < .1 && !mon.has_flag(MF_NOHEAD)) {
+   message = "Headshot!";
+   dam = rng(5 * dam, 8 * dam);
+   p.practice(firing->skill_used, 5);
+  } else if (goodhit < .2) {
+   message = "Critical!";
+   dam = rng(dam * 2, dam * 3);
+   p.practice(firing->skill_used, 2);
+  } else if (goodhit < .4) {
+   dam = rng(int(dam * .9), int(dam * 1.5));
+   p.practice(firing->skill_used, rng(0, 2));
+  } else if (goodhit <= .7) {
+   message = "Grazing hit.";
+   dam = rng(0, dam);
+  } else
+   dam = 0;
+// Find the zombie at (x, y) and hurt them, MAYBE kill them!
+  if (dam > 0) {
+   mon.moves -= dam * 5;
+   if (&p == &(g->u) && u_see_mon)
+    g->add_msg("%s You hit the %s for %d damage.", message.c_str(),
+            mon.name().c_str(), dam);
+   else if (u_see_mon)
+    g->add_msg("%s %s shoots the %s.", message.c_str(), p.name.c_str(),
+            mon.name().c_str());
+   if (mon.hurt(dam))
+    g->kill_mon(g->mon_at(mon.posx, mon.posy));
+   else if (p.weapon.curammo->item_flags != 0)
+    g->hit_monster_with_flags(mon, p.weapon.curammo->item_flags);
+   dam = 0;
+  }
+ }
+}
+
+void shoot_player(game *g, player &p, player *h, int &dam, double goodhit)
+{
+ it_gun* firing = dynamic_cast<it_gun*>(p.weapon.type);
+ body_part hit;
+ int side = rng(0, 1), junk;
+ if (goodhit < .05) {
+  hit = bp_eyes;
+  dam = rng(3 * dam, 5 * dam);
+  p.practice(firing->skill_used, 5);
+ } else if (goodhit < .1) {
+  if (one_in(6))
+   hit = bp_eyes;
+  else if (one_in(4))
+   hit = bp_mouth;
+  else
+   hit = bp_head;
+  dam = rng(2 * dam, 5 * dam);
+  p.practice(firing->skill_used, 5);
+ } else if (goodhit < .2) {
+  hit = bp_torso;
+  dam = rng(dam, 2 * dam);
+  p.practice(firing->skill_used, 2);
+ } else if (goodhit < .4) {
+  if (one_in(3))
+   hit = bp_torso;
+  else if (one_in(2))
+   hit = bp_arms;
+  else
+   hit = bp_legs;
+  dam = rng(int(dam * .9), int(dam * 1.5));
+  p.practice(firing->skill_used, rng(0, 1));
+ } else if (goodhit < .5) {
+  if (one_in(2))
+   hit = bp_arms;
+  else
+   hit = bp_legs;
+  dam = rng(dam / 2, dam);
+ } else {
+  dam = 0;
+ }
+ if (dam > 0) {
+  h->moves -= rng(0, dam);
+  if (h == &(g->u))
+   g->add_msg("%s shoots your %s for %d damage!", p.name.c_str(),
+              body_part_name(hit, side).c_str(), dam);
+  else {
+   if (&p == &(g->u))
+    g->add_msg("You shoot %s's %s.", h->name.c_str(),
+               body_part_name(hit, side).c_str());
+   else if (g->u_see(h->posx, h->posy, junk))
+    g->add_msg("%s shoots %s's %s.",
+               (g->u_see(p.posx, p.posy, junk) ? p.name.c_str() : "Someone"),
+               h->name.c_str(), body_part_name(hit, side).c_str());
+  }
+  h->hit(g, hit, side, 0, dam);
+  if (h != &(g->u)) {
+   int npcdex = g->npc_at(h->posx, h->posy);
+   if (g->active_npc[npcdex].hp_cur[hp_head]  <= 0 ||
+       g->active_npc[npcdex].hp_cur[hp_torso] <= 0   ) {
+    g->active_npc[npcdex].die(g, !p.is_npc());
+    g->active_npc.erase(g->active_npc.begin() + npcdex);
+   }
+  }
+ }
+}
+
+void splatter(game *g, std::vector<point> trajectory, int dam, monster* mon)
+{
+ field_id blood = fd_blood;
+ if (mon != NULL) {
+  if (!mon->made_of(FLESH))
+   return;
+  if (mon->type->dies == &mdeath::boomer)
+   blood = fd_bile;
+  else if (mon->type->dies == &mdeath::acid)
+   blood = fd_acid;
+ }
+
+ int distance = 1;
+ if (dam > 50)
+  distance = 3;
+ else if (dam > 15)
+  distance = 2;
+
+ std::vector<point> spurt = continue_line(trajectory, distance);
+
+ for (int i = 0; i < spurt.size(); i++) {
+  int tarx = spurt[i].x, tary = spurt[i].y;
+  if (g->m.field_at(tarx, tary).type == blood &&
+      g->m.field_at(tarx, tary).density < 3)
+   g->m.field_at(tarx, tary).density++;
+  else
+   g->m.add_field(g, tarx, tary, blood, 1);
+ }
+}
