@@ -9,8 +9,8 @@ class game;
 enum season_type {
  SPRING = 0,
  SUMMER = 1,
- WINTER = 2,
- AUTUMN = 3
+ AUTUMN = 2,
+ WINTER = 3
 #define FALL AUTUMN
 };
 
@@ -53,6 +53,7 @@ struct weather_datum
  int avg_temperature[4]; // Spring, Summer, Winter, Fall
  int ranged_penalty;
  int sight_penalty; // Penalty to max sight range
+ bool dangerous; // If true, our activity gets interrupted
  void (weather_effect::*effect)(game *);
 };
 
